@@ -35,7 +35,7 @@ pub fn match_content_type<S>(data: &[u8], expected_content_type: S) -> anyhow::R
 
 pub fn convert_data(data: &Value) -> Vec<u8> {
   match data {
-    &Value::String(ref s) => base64::decode(s.as_str()).unwrap_or_else(|_| s.clone().into_bytes()),
+    Value::String(s) => base64::decode(s.as_str()).unwrap_or_else(|_| s.clone().into_bytes()),
     _ => data.to_string().into_bytes()
   }
 }
@@ -47,35 +47,38 @@ pub fn match_octet_stream(expected: &dyn HttpPart, actual: &dyn HttpPart, contex
   debug!("matching binary contents ({} bytes)", actual.len());
   let path = vec!["$"];
   if context.matcher_is_defined(&path) {
-    match context.select_best_matcher(&path) {
-      None => mismatches.push(Mismatch::BodyMismatch {
+    let matchers = context.select_best_matcher(&path);
+    if matchers.is_empty() {
+      mismatches.push(Mismatch::BodyMismatch {
         path: "$".into(),
         expected: Some(expected),
         actual: Some(actual),
-        mismatch: format!("No matcher found for category 'body' and path '{}'", path.iter().join("."))}),
-      Some(ref rulelist) => {
-        let results = rulelist.rules.iter().map(|rule|
-          expected.matches_with(&actual, rule)).collect::<Vec<anyhow::Result<()>>>();
-        match rulelist.rule_logic {
-          RuleLogic::And => for result in results {
-            if let Err(err) = result {
-              mismatches.push(Mismatch::BodyMismatch {
-                path: "$".into(),
-                expected: Some(expected.clone()),
-                actual: Some(actual.clone()),
-                mismatch: err.to_string() })
-            }
-          },
-          RuleLogic::Or => {
-            if results.iter().all(|result| result.is_err()) {
-              for result in results {
-                if let Err(err) = result {
-                  mismatches.push(Mismatch::BodyMismatch {
-                    path: "$".into(),
-                    expected: Some(expected.clone()),
-                    actual: Some(actual.clone()),
-                    mismatch: err.to_string() })
-                }
+        mismatch: format!("No matcher found for category 'body' and path '{}'", path.iter().join(".")),
+      })
+    } else {
+      let results = matchers.rules.iter().map(|rule|
+        expected.matches_with(&actual, rule, matchers.cascaded)).collect::<Vec<anyhow::Result<()>>>();
+      match matchers.rule_logic {
+        RuleLogic::And => for result in results {
+          if let Err(err) = result {
+            mismatches.push(Mismatch::BodyMismatch {
+              path: "$".into(),
+              expected: Some(expected.clone()),
+              actual: Some(actual.clone()),
+              mismatch: err.to_string(),
+            })
+          }
+        },
+        RuleLogic::Or => {
+          if results.iter().all(|result| result.is_err()) {
+            for result in results {
+              if let Err(err) = result {
+                mismatches.push(Mismatch::BodyMismatch {
+                  path: "$".into(),
+                  expected: Some(expected.clone()),
+                  actual: Some(actual.clone()),
+                  mismatch: err.to_string(),
+                })
               }
             }
           }
@@ -88,7 +91,7 @@ pub fn match_octet_stream(expected: &dyn HttpPart, actual: &dyn HttpPart, contex
       expected: Some(expected.clone()),
       actual: Some(actual.clone()),
       mismatch: format!("Expected binary data of {} bytes but received {} bytes",
-                        expected.len(), actual.len())
+                        expected.len(), actual.len()),
     });
   }
 
@@ -134,27 +137,21 @@ pub fn match_mime_multipart(expected: &dyn HttpPart, actual: &dyn HttpPart, cont
   let expected_parts = parse_multipart(expected.body().value().unwrap_or_default().reader(), expected.headers());
 
   if expected_parts.is_err() || actual_parts.is_err() {
-    match expected_parts {
-      Err(e) => {
-        mismatches.push(Mismatch::BodyMismatch {
-          path: "$".into(),
-          expected: expected.body().value(),
-          actual: actual.body().value(),
-          mismatch: format!("Failed to parse the expected body as a MIME multipart body: '{}'", e)
-        });
-      },
-      _ => ()
+    if let Err(e) = expected_parts {
+      mismatches.push(Mismatch::BodyMismatch {
+        path: "$".into(),
+        expected: expected.body().value(),
+        actual: actual.body().value(),
+        mismatch: format!("Failed to parse the expected body as a MIME multipart body: '{}'", e)
+      });
     }
-    match actual_parts {
-      Err(e) => {
-        mismatches.push(Mismatch::BodyMismatch {
-          path: "$".into(),
-          expected: expected.body().value(),
-          actual: actual.body().value(),
-          mismatch: format!("Failed to parse the actual body as a MIME multipart body: '{}'", e)
-        });
-      },
-      _ => ()
+    if let Err(e) = actual_parts {
+      mismatches.push(Mismatch::BodyMismatch {
+        path: "$".into(),
+        expected: expected.body().value(),
+        actual: actual.body().value(),
+        mismatch: format!("Failed to parse the actual body as a MIME multipart body: '{}'", e)
+      });
     }
   } else {
     let actual_parts = actual_parts.unwrap();
@@ -216,13 +213,13 @@ fn match_mime_part(expected: &MimePart, actual: &MimePart, context: &MatchingCon
   }
 }
 
-fn match_field(key: &String, expected: &String, actual: &String, context: &MatchingContext) -> Result<(), Vec<Mismatch>> {
-  let path = vec![ROOT, key.as_str()];
+fn match_field(key: &str, expected: &str, actual: &str, context: &MatchingContext) -> Result<(), Vec<Mismatch>> {
+  let path = vec![ROOT, key];
   let matcher_result = if context.matcher_is_defined(&path) {
     debug!("Calling match_values for path $.{}", key);
-    match_values(&path, context, expected.as_str(), actual.as_str())
+    match_values(&path, context, expected, actual)
   } else {
-    expected.as_str().matches_with(actual.as_str(), &MatchingRule::Equality).map_err(|err|
+    expected.matches_with(actual, &MatchingRule::Equality, false).map_err(|err|
       vec![format!("MIME part '{}': {}", key, err)]
     )
   };
@@ -248,14 +245,14 @@ fn first(bytes: &[u8], len: usize) -> &[u8] {
 }
 
 impl Matches<&MimeFile> for &MimeFile {
-  fn matches_with(&self, actual: &MimeFile, matcher: &MatchingRule) -> anyhow::Result<()> {
+  fn matches_with(&self, actual: &MimeFile, matcher: &MatchingRule, _cascaded: bool) -> anyhow::Result<()> {
     debug!("FilePart: comparing binary data to '{:?}' using {:?}", actual.content_type, matcher);
     match matcher {
       MatchingRule::Regex(ref regex) => {
         match Regex::new(regex) {
           Ok(re) => {
             match from_utf8(&*actual.data) {
-              Ok(a) => if re.is_match(&a) {
+              Ok(a) => if re.is_match(a) {
                   Ok(())
                 } else {
                   Err(anyhow!("Expected binary file '{}' to match '{}'", actual.filename, regex))
@@ -293,8 +290,8 @@ impl Matches<&MimeFile> for &MimeFile {
   }
 }
 
-fn match_file(key: &String, expected: &MimeFile, actual: &MimeFile, context: &MatchingContext) -> Result<(), Vec<Mismatch>> {
-  let path = vec![ROOT, key.as_str()];
+fn match_file(key: &str, expected: &MimeFile, actual: &MimeFile, context: &MatchingContext) -> Result<(), Vec<Mismatch>> {
+  let path = vec![ROOT, key];
   let matcher_result = if context.matcher_is_defined(&path) {
     debug!("Calling match_values for path $.{}", key);
     match_values( &path, context, expected, actual).map_err(|errors| {
@@ -305,28 +302,26 @@ fn match_file(key: &String, expected: &MimeFile, actual: &MimeFile, context: &Ma
         mismatch: format!("MIME part '{}': {}", key, err)
       }).collect()
     })
+  } else if expected.content_type == actual.content_type {
+    expected.matches_with(actual, &MatchingRule::Equality, false).map_err(|err|
+      vec![Mismatch::BodyMismatch {
+        path: path.join("."),
+        expected: None,
+        actual: None,
+        mismatch: format!("MIME part '{}': {}", key, err)
+      }]
+    )
   } else {
-    if expected.content_type == actual.content_type {
-      expected.matches_with(actual, &MatchingRule::Equality).map_err(|err|
-        vec![Mismatch::BodyMismatch {
-          path: path.join("."),
-          expected: None,
-          actual: None,
-          mismatch: format!("MIME part '{}': {}", key, err)
-        }]
-      )
-    } else {
-      let expected_str = expected.content_type.as_ref().map(|mime| mime.to_string()).unwrap_or_else(|| format!("None"));
-      let actual_str = actual.content_type.as_ref().map(|mime| mime.to_string()).unwrap_or_else(|| format!("None"));
-      Err(vec![Mismatch::BodyTypeMismatch {
-        expected: expected_str.clone(),
-        actual: actual_str.clone(),
-        mismatch: format!("Expected MIME part '{}' with content type '{}' but was '{}'",
-                          key, expected_str, actual_str),
-        expected_body: None,
-        actual_body: None
-      }])
-    }
+    let expected_str = expected.content_type.as_ref().map(|mime| mime.to_string()).unwrap_or_else(|| "None".to_string());
+    let actual_str = actual.content_type.as_ref().map(|mime| mime.to_string()).unwrap_or_else(|| "None".to_string());
+    Err(vec![Mismatch::BodyTypeMismatch {
+      expected: expected_str.clone(),
+      actual: actual_str.clone(),
+      mismatch: format!("Expected MIME part '{}' with content type '{}' but was '{}'",
+                        key, expected_str, actual_str),
+      expected_body: None,
+      actual_body: None
+    }])
   };
   debug!("Comparing '{:?}' to '{:?}' at path '{}' -> {:?}", expected, actual, path.join("."), matcher_result);
   matcher_result
@@ -379,10 +374,10 @@ fn get_multipart_boundary(headers: &Option<HashMap<String, Vec<String>>>) -> Res
   let mime: mime::Mime = content_type.parse().map_err(|e| format!("invalid content-type: {}", e))?;
 
   if mime.type_() != mime::MULTIPART || mime.subtype() != mime::FORM_DATA {
-    return Err(format!("expected content-type to be multipart/form-data"));
+    return Err("expected content-type to be multipart/form-data".to_string());
   }
 
-  let boundary = mime.get_param(mime::BOUNDARY).ok_or_else(|| format!("no boundary in content-type"))?;
+  let boundary = mime.get_param(mime::BOUNDARY).ok_or_else(|| "no boundary in content-type".to_string())?;
 
   Ok(boundary.as_str().to_owned())
 }
@@ -431,7 +426,7 @@ mod tests {
     let body = Bytes::from("not a multipart body");
     let request = Request {
       headers: Some(hashmap!{}),
-      body: OptionalBody::Present(body, None),
+      body: OptionalBody::Present(body, None, None),
       ..Request::default()
     };
     let context = MatchingContext::with_config(DiffConfig::AllowUnexpectedKeys);
@@ -462,7 +457,7 @@ mod tests {
       --1234--\r\n");
     let expected = Request {
       headers: Some(hashmap!{ "Content-Type".into() => vec![ "multipart/form-data; boundary=1234".into() ] }),
-      body: OptionalBody::Present(expected_body, None),
+      body: OptionalBody::Present(expected_body, None, None),
       ..Request::default()
     };
     let actual_body = Bytes::from("--1234\r\n\
@@ -479,7 +474,7 @@ mod tests {
       --1234--\r\n");
     let actual = Request {
       headers: Some(hashmap!{ "Content-Type".into() => vec![ "multipart/form-data; boundary=1234".into() ] }),
-      body: OptionalBody::Present(actual_body, None),
+      body: OptionalBody::Present(actual_body, None, None),
       ..Request::default()
     };
     let context = MatchingContext::with_config(DiffConfig::AllowUnexpectedKeys);
@@ -505,7 +500,7 @@ mod tests {
       --1234--\r\n");
     let expected = Request {
       headers: Some(hashmap!{ "Content-Type".into() => vec![ "multipart/form-data; boundary=1234".into() ] }),
-      body: OptionalBody::Present(expected_body, None),
+      body: OptionalBody::Present(expected_body, None, None),
       ..Request::default()
     };
     let actual_body = Bytes::from("--1234\r\n\
@@ -514,7 +509,7 @@ mod tests {
       --1234--\r\n");
     let actual = Request {
       headers: Some(hashmap!{ "Content-Type".into() => vec![ "multipart/form-data; boundary=1234".into() ] }),
-      body: OptionalBody::Present(actual_body, None),
+      body: OptionalBody::Present(actual_body, None, None),
       ..Request::default()
     };
     let context = MatchingContext::with_config(DiffConfig::AllowUnexpectedKeys);
@@ -543,7 +538,7 @@ mod tests {
       --1234--\r\n");
     let expected = Request {
       headers: Some(hashmap!{ "Content-Type".into() => vec![ "multipart/form-data; boundary=1234".into() ] }),
-      body: OptionalBody::Present(expected_body, None),
+      body: OptionalBody::Present(expected_body, None, None),
       ..Request::default()
     };
     let actual_body = Bytes::from("--4567\r\n\
@@ -560,7 +555,7 @@ mod tests {
       --4567--\r\n");
     let actual = Request {
       headers: Some(hashmap!{ "Content-Type".into() => vec![ "multipart/form-data; boundary=4567".into() ] }),
-      body: OptionalBody::Present(actual_body, None),
+      body: OptionalBody::Present(actual_body, None, None),
       ..Request::default()
     };
     let context = MatchingContext::with_config(DiffConfig::AllowUnexpectedKeys);
@@ -585,7 +580,7 @@ mod tests {
       --1234--\r\n");
     let expected = Request {
       headers: Some(hashmap!{ "Content-Type".into() => vec![ "multipart/form-data; boundary=1234".into() ] }),
-      body: OptionalBody::Present(expected_body, None),
+      body: OptionalBody::Present(expected_body, None, None),
       matching_rules: matchingrules! {
         "body" => {
           "$.name" => [ MatchingRule::Regex(s!("^\\w+$")) ],
@@ -608,11 +603,11 @@ mod tests {
       --4567--\r\n");
     let actual = Request {
       headers: Some(hashmap!{ "Content-Type".into() => vec![ "multipart/form-data; boundary=4567".into() ] }),
-      body: OptionalBody::Present(actual_body, None),
+      body: OptionalBody::Present(actual_body, None, None),
       ..Request::default()
     };
     let context = MatchingContext::new(DiffConfig::AllowUnexpectedKeys,
-      &expected.matching_rules.rules_for_category("body").unwrap());
+      &expected.matching_rules.rules_for_category("body").unwrap(), &hashmap!{});
 
     let result = match_mime_multipart(&expected, &actual, &context);
 
@@ -635,7 +630,7 @@ mod tests {
       --1234--\r\n");
     let expected = Request {
       headers: Some(hashmap!{ "Content-Type".into() => vec![ "multipart/form-data; boundary=1234".into() ] }),
-      body: OptionalBody::Present(expected_body, None),
+      body: OptionalBody::Present(expected_body, None, None),
       ..Request::default()
     };
     let actual_body = Bytes::from("--4567\r\n\
@@ -652,7 +647,7 @@ mod tests {
       --4567--\r\n");
     let actual = Request {
       headers: Some(hashmap!{ "Content-Type".into() => vec![ "multipart/form-data; boundary=4567".into() ] }),
-      body: OptionalBody::Present(actual_body, None),
+      body: OptionalBody::Present(actual_body, None, None),
       ..Request::default()
     };
     let context = MatchingContext::with_config(DiffConfig::AllowUnexpectedKeys);
@@ -665,6 +660,7 @@ mod tests {
   }
 
   #[test]
+  #[cfg(not(target_os = "windows"))] // Requires shared mime-info db, not available on Windows
   fn match_mime_multipart_content_type_matcher() {
     let expected_body = Bytes::from("--1234\r\n\
       Content-Type: text/plain\r\n\
@@ -680,7 +676,7 @@ mod tests {
       --1234--\r\n");
     let expected = Request {
       headers: Some(hashmap!{ "Content-Type".into() => vec![ "multipart/form-data; boundary=1234".into() ] }),
-      body: OptionalBody::Present(expected_body, None),
+      body: OptionalBody::Present(expected_body, None, None),
       matching_rules: matchingrules! {
         "body" => {
           "$.file" => [ MatchingRule::ContentType("image/png".into()) ]
@@ -708,11 +704,11 @@ mod tests {
     actual_body.extend_from_slice("\r\n--4567--\r\n".as_bytes());
     let actual = Request {
       headers: Some(hashmap!{ "Content-Type".into() => vec![ "multipart/form-data; boundary=4567".into() ] }),
-      body: OptionalBody::Present(actual_body.freeze(), None),
+      body: OptionalBody::Present(actual_body.freeze(), None, None),
       ..Request::default()
     };
     let context = MatchingContext::new(DiffConfig::AllowUnexpectedKeys,
-      &expected.matching_rules.rules_for_category("body").unwrap());
+      &expected.matching_rules.rules_for_category("body").unwrap(), &hashmap!{});
 
     let result = match_mime_multipart(&expected, &actual, &context);
 
@@ -720,6 +716,7 @@ mod tests {
   }
 
   #[test]
+  #[cfg(not(target_os = "windows"))] // Requires shared mime-info db, not available on Windows
   fn match_mime_multipart_content_type_matcher_with_mismatch() {
     let expected_body = Bytes::from("--1234\r\n\
       Content-Type: text/plain\r\n\
@@ -735,7 +732,7 @@ mod tests {
       --1234--\r\n");
     let expected = Request {
       headers: Some(hashmap!{ "Content-Type".into() => vec![ "multipart/form-data; boundary=1234".into() ] }),
-      body: OptionalBody::Present(expected_body, None),
+      body: OptionalBody::Present(expected_body, None, None),
       matching_rules: matchingrules! {
         "body" => {
           "$.file" => [ MatchingRule::ContentType("application/jpeg".into()) ]
@@ -757,11 +754,11 @@ mod tests {
       --4567--\r\n");
     let actual = Request {
       headers: Some(hashmap!{ "Content-Type".into() => vec![ "multipart/form-data; boundary=4567".into() ] }),
-      body: OptionalBody::Present(actual_body, None),
+      body: OptionalBody::Present(actual_body, None, None),
       ..Request::default()
     };
     let context = MatchingContext::new(DiffConfig::AllowUnexpectedKeys,
-      &expected.matching_rules.rules_for_category("body").unwrap());
+      &expected.matching_rules.rules_for_category("body").unwrap(), &hashmap!{});
 
     let result = match_mime_multipart(&expected, &actual, &context);
 
