@@ -7,6 +7,7 @@ use anyhow::anyhow;
 use difference::*;
 use log::*;
 use onig::Regex;
+use semver::Version;
 use serde_json::{json, Value};
 
 use pact_models::http_parts::HttpPart;
@@ -23,35 +24,35 @@ use super::Mismatch;
 
 fn type_of(json: &Value) -> String {
   match json {
-    &Value::Object(_) => "Map",
-    &Value::Array(_) => "List",
-    &Value::Null => "Null",
-    &Value::Bool(_) => "Boolean",
-    &Value::Number(_) => "Number",
-    &Value::String(_) => "String"
+    Value::Object(_) => "Map",
+    Value::Array(_) => "List",
+    Value::Null => "Null",
+    Value::Bool(_) => "Boolean",
+    Value::Number(_) => "Number",
+    Value::String(_) => "String"
   }.to_string()
 }
 
 impl Matches<Value> for Value {
-  fn matches_with(&self, actual: Value, matcher: &MatchingRule) -> anyhow::Result<()> {
-    self.matches_with(&actual, matcher)
+  fn matches_with(&self, actual: Value, matcher: &MatchingRule, cascaded: bool) -> anyhow::Result<()> {
+    self.matches_with(&actual, matcher, cascaded)
   }
 }
 
 impl Matches<&Value> for &Value {
-  fn matches_with(&self, actual: &Value, matcher: &MatchingRule) -> anyhow::Result<()> {
-    (*self).matches_with(actual, matcher)
+  fn matches_with(&self, actual: &Value, matcher: &MatchingRule, cascaded: bool) -> anyhow::Result<()> {
+    (*self).matches_with(actual, matcher, cascaded)
   }
 }
 
 impl Matches<&Value> for Value {
-  fn matches_with(&self, actual: &Value, matcher: &MatchingRule) -> anyhow::Result<()> {
+  fn matches_with(&self, actual: &Value, matcher: &MatchingRule, cascaded: bool) -> anyhow::Result<()> {
     let result = match matcher {
       MatchingRule::Regex(regex) => {
         match Regex::new(regex) {
           Ok(re) => {
             let actual_str = match actual {
-              &Value::String(ref s) => s.clone(),
+              Value::String(ref s) => s.clone(),
               _ => actual.to_string()
             };
             if re.is_match(&actual_str) {
@@ -65,7 +66,7 @@ impl Matches<&Value> for Value {
       },
       MatchingRule::Include(substr) => {
         let actual_str = match actual {
-          &Value::String(ref s) => s.clone(),
+          Value::String(ref s) => s.clone(),
           _ => actual.to_string()
         };
         if actual_str.contains(substr) {
@@ -87,7 +88,7 @@ impl Matches<&Value> for Value {
       },
       MatchingRule::MinType(min) => {
         match (self, actual) {
-          (&Value::Array(_), &Value::Array(ref actual_array)) => if actual_array.len() < *min {
+          (&Value::Array(_), &Value::Array(ref actual_array)) => if !cascaded && actual_array.len() < *min {
             Err(anyhow!("Expected '{}' to have at least {} item(s)", json_to_string(actual), min))
           } else {
             Ok(())
@@ -102,7 +103,7 @@ impl Matches<&Value> for Value {
       },
       MatchingRule::MaxType(max) => {
         match (self, actual) {
-          (&Value::Array(_), &Value::Array(ref actual_array)) => if actual_array.len() > *max {
+          (&Value::Array(_), &Value::Array(ref actual_array)) => if !cascaded && actual_array.len() > *max {
             Err(anyhow!("Expected '{}' to have at most {} item(s)", json_to_string(actual), max))
           } else {
             Ok(())
@@ -117,9 +118,9 @@ impl Matches<&Value> for Value {
       },
       MatchingRule::MinMaxType(min, max) => {
         match (self, actual) {
-          (&Value::Array(_), &Value::Array(ref actual_array)) => if actual_array.len() < *min {
+          (&Value::Array(_), &Value::Array(ref actual_array)) => if !cascaded && actual_array.len() < *min {
             Err(anyhow!("Expected '{}' to have at least {} item(s)", json_to_string(actual), min))
-          } else if actual_array.len() > *max {
+          } else if !cascaded && actual_array.len() > *max {
             Err(anyhow!("Expected '{}' to have at most {} item(s)", json_to_string(actual), max))
           } else {
             Ok(())
@@ -140,7 +141,7 @@ impl Matches<&Value> for Value {
         }
       },
       MatchingRule::Null => match actual {
-        &Value::Null => Ok(()),
+        Value::Null => Ok(()),
         _ => Err(anyhow!("Expected '{}' to be a null value", json_to_string(actual)))
       },
       MatchingRule::Integer => if actual.is_i64() || actual.is_u64() {
@@ -183,6 +184,32 @@ impl Matches<&Value> for Value {
         }
         _ => Err(anyhow!("Expected '{}' to match a boolean", json_to_string(actual)))
       }
+      MatchingRule::NotEmpty => match actual {
+        Value::Null => Err(anyhow!("Expected non-empty but got a NULL")),
+        Value::String(s) => if s.is_empty() {
+          Err(anyhow!("Expected an non-empty string"))
+        } else {
+          Ok(())
+        }
+        Value::Array(a) => if a.is_empty() {
+          Err(anyhow!("Expected an non-empty array"))
+        } else {
+          Ok(())
+        }
+        Value::Object(o) => if o.is_empty() {
+          Err(anyhow!("Expected an non-empty object"))
+        } else {
+          Ok(())
+        }
+        _ => Ok(())
+      }
+      MatchingRule::Semver => match actual {
+        Value::String(s) => match Version::parse(s) {
+          Ok(_) => Ok(()),
+          Err(err) => Err(anyhow!("'{}' is not a valid semantic version - {}", s, err))
+        }
+        _ => Err(anyhow!("Expected something that matches a semantic version, but got '{}'", actual))
+      }
       _ => Ok(())
     };
     debug!("JSON -> JSON: Comparing '{}' to '{}' using {:?} -> {:?}", self, actual, matcher, result);
@@ -197,40 +224,34 @@ pub fn match_json(expected: &dyn HttpPart, actual: &dyn HttpPart, context: &Matc
 
   if expected_json.is_err() || actual_json.is_err() {
     let mut mismatches = vec![];
-    match expected_json {
-      Err(e) => {
-        mismatches.push(Mismatch::BodyMismatch {
-          path: "$".to_string(),
-          expected: expected.body().value(),
-          actual: actual.body().value(),
-          mismatch: format!("Failed to parse the expected body: '{}'", e),
-        });
-      },
-      _ => ()
+    if let Err(e) = expected_json {
+      mismatches.push(Mismatch::BodyMismatch {
+        path: "$".to_string(),
+        expected: expected.body().value(),
+        actual: actual.body().value(),
+        mismatch: format!("Failed to parse the expected body: '{}'", e),
+      });
     }
-    match actual_json {
-      Err(e) => {
-        mismatches.push(Mismatch::BodyMismatch {
-          path: "$".to_string(),
-          expected: expected.body().value(),
-          actual: actual.body().value(),
-          mismatch: format!("Failed to parse the actual body: '{}'", e),
-        });
-      },
-      _ => ()
+    if let Err(e) = actual_json {
+      mismatches.push(Mismatch::BodyMismatch {
+        path: "$".to_string(),
+        expected: expected.body().value(),
+        actual: actual.body().value(),
+        mismatch: format!("Failed to parse the actual body: '{}'", e),
+      });
     }
     Err(mismatches.clone())
   } else {
-    compare(&vec!["$"], &expected_json.unwrap(), &actual_json.unwrap(), context)
+    compare(&["$"], &expected_json.unwrap(), &actual_json.unwrap(), context)
   }
 }
 
 fn walk_json(json: &Value, path: &mut dyn Iterator<Item=&str>) -> Option<Value> {
   match path.next() {
     Some(p) => match json {
-      &Value::Object(_) => json.get(p).map(|json| json.clone()),
-      &Value::Array(ref array) => match usize::from_str(p) {
-        Ok(index) => array.get(index).map(|json| json.clone()),
+      Value::Object(_) => json.get(p).cloned(),
+      Value::Array(ref array) => match usize::from_str(p) {
+        Ok(index) => array.get(index).cloned(),
         Err(_) => None
       },
       _ => None
@@ -240,7 +261,7 @@ fn walk_json(json: &Value, path: &mut dyn Iterator<Item=&str>) -> Option<Value>
 }
 
 /// Returns a diff of the expected versus the actual JSON bodies, focusing on a particular path
-pub fn display_diff(expected: &String, actual: &String, path: &str, indent: &str) -> String {
+pub fn display_diff(expected: &str, actual: &str, path: &str, indent: &str) -> String {
   let expected_body = if expected.is_empty() {
     Value::String("".into())
   } else {
@@ -327,9 +348,9 @@ fn compare_maps(path: &[&str], expected: &serde_json::Map<String, Value>, actual
 
     if context.matcher_is_defined(path) {
       debug!("compare_maps: Matcher is defined for path {}", spath);
-      for matcher in context.select_best_matcher(path).unwrap().rules {
-        result = merge_result(result,compare_maps_with_matchingrule(&matcher, path, &expected, &actual, &context, &mut |p, expected, actual| {
-          compare(&p, expected, actual, context)
+      for matcher in context.select_best_matcher(path).rules {
+        result = merge_result(result,compare_maps_with_matchingrule(&matcher, path, &expected, &actual, context, &mut |p, expected, actual| {
+          compare(p, expected, actual, context)
         }));
       }
     } else {
@@ -346,13 +367,13 @@ fn compare_maps(path: &[&str], expected: &serde_json::Map<String, Value>, actual
   }
 }
 
-fn compare_lists(path: &[&str], expected: &Vec<Value>, actual: &Vec<Value>,
+fn compare_lists(path: &[&str], expected: &[Value], actual: &[Value],
                  context: &MatchingContext) -> Result<(), Vec<Mismatch>> {
   let spath = path.join(".");
   if context.matcher_is_defined(path) {
-    log::debug!("compare_lists: matcher defined for path '{}'", spath);
+    debug!("compare_lists: matcher defined for path '{}'", spath);
     let mut result = Ok(());
-    for matcher in context.select_best_matcher(path).unwrap().rules {
+    for matcher in context.select_best_matcher(path).rules {
       let values_result = compare_lists_with_matchingrule(&matcher, path, expected, actual, context, &|p, expected, actual, context| {
         compare(p, expected, actual, context)
       });
@@ -382,7 +403,7 @@ fn compare_lists(path: &[&str], expected: &Vec<Value>, actual: &Vec<Value>,
   }
 }
 
-fn compare_list_content(path: &[&str], expected: &Vec<Value>, actual: &Vec<Value>, context: &MatchingContext) -> Result<(), Vec<Mismatch>> {
+fn compare_list_content(path: &[&str], expected: &[Value], actual: &[Value], context: &MatchingContext) -> Result<(), Vec<Mismatch>> {
   let mut result = Ok(());
   for (index, value) in expected.iter().enumerate() {
     let ps = index.to_string();
@@ -402,11 +423,11 @@ fn compare_list_content(path: &[&str], expected: &Vec<Value>, actual: &Vec<Value
 }
 
 fn compare_values(path: &[&str], expected: &Value, actual: &Value, context: &MatchingContext) -> Result<(), Vec<Mismatch>> {
-  let matcher_result = if context.matcher_is_defined(&path) {
+  let matcher_result = if context.matcher_is_defined(path) {
     debug!("compare_values: Calling match_values for path {}", path.join("."));
     match_values(path, context, expected, actual)
   } else {
-    expected.matches_with(actual, &MatchingRule::Equality).map_err(|err| vec![err.to_string()])
+    expected.matches_with(actual, &MatchingRule::Equality, false).map_err(|err| vec![err.to_string()])
   };
   log::debug!("compare_values: Comparing '{:?}' to '{:?}' at path '{}' -> {:?}", expected, actual, path.join("."), matcher_result);
   matcher_result.map_err(|messages| {
@@ -427,6 +448,7 @@ mod tests {
 
   use expectest::expect;
   use expectest::prelude::*;
+  use maplit::hashmap;
 
   use pact_models::{matchingrules, matchingrules_list};
   use pact_models::bodies::OptionalBody;
@@ -440,7 +462,7 @@ mod tests {
   use super::*;
 
   macro_rules! request {
-    ($e:expr) => (Request { body: OptionalBody::Present($e.into(), None), .. Request::default() })
+    ($e:expr) => (Request { body: OptionalBody::Present($e.into(), None, None), .. Request::default() })
   }
 
   #[test]
@@ -586,7 +608,7 @@ mod tests {
     expect!(result).to(be_ok());
 
     let result = match_json(&val1.clone(), &val2.clone(), &MatchingContext::with_config(DiffConfig::AllowUnexpectedKeys));
-    expect!(mismatch_message(&result)).to(be_equal_to(s!("Expected 'null' to be equal to '33'")));
+    expect!(mismatch_message(&result)).to(be_equal_to(s!("Expected '' to be equal to '33'")));
     expect!(result).to(be_err().value(vec![ Mismatch::BodyMismatch {
       path: s!("$"),
       expected: val1.clone().body.value(),
@@ -640,17 +662,14 @@ mod tests {
         actual: Some("[11,44,33,66]".into()), mismatch: s!("")}));
     expect!(mismatch.description()).to(be_equal_to(s!("$ -> Expected a List with 3 elements but received 4 elements")));
 
-    let result = match_json(&val2.clone(), &val4.clone(), &MatchingContext::new(DiffConfig::AllowUnexpectedKeys, &matchingrules!{
+    let context = MatchingContext::new(DiffConfig::AllowUnexpectedKeys, &matchingrules! {
         "body" => {
             "$" => [ MatchingRule::Type ]
         }
-    }.rules_for_category("body").unwrap()));
+    }.rules_for_category("body").unwrap(), &hashmap!{});
+    let result = match_json(&val2.clone(), &val4.clone(), &context);
     expect!(result).to(be_ok());
-    let result = match_json(&val4, &val2, &MatchingContext::new(DiffConfig::AllowUnexpectedKeys, &matchingrules!{
-        "body" => {
-            "$" => [ MatchingRule::Type ]
-        }
-    }.rules_for_category("body").unwrap()));
+    let result = match_json(&val4, &val2, &context);
     expect!(result).to(be_ok());
   }
 
@@ -721,118 +740,122 @@ mod tests {
       "body" => {
         "$.*" => [ MatchingRule::Type ]
       }
-    }.rules_for_category("body").unwrap()));
+    }.rules_for_category("body").unwrap(), &hashmap!{}));
     expect!(result).to(be_ok());
   }
 
     #[test]
     fn equality_matcher_test() {
         let matcher = MatchingRule::Equality;
-        expect!(Value::String("100".into()).matches_with(Value::String("100".into()), &matcher)).to(be_ok());
-        expect!(Value::String("100".into()).matches_with(Value::String("101".into()), &matcher)).to(be_err());
-        expect!(Value::String("100".into()).matches_with(json!(100), &matcher)).to(be_err());
+        expect!(Value::String("100".into()).matches_with(Value::String("100".into()), &matcher, false)).to(be_ok());
+        expect!(Value::String("100".into()).matches_with(Value::String("101".into()), &matcher, false)).to(be_err());
+        expect!(Value::String("100".into()).matches_with(json!(100), &matcher, false)).to(be_err());
     }
 
     #[test]
     fn regex_matcher_test() {
         let matcher = MatchingRule::Regex("^\\d+$".into());
-        expect!(Value::String("100".into()).matches_with(Value::String("100".into()), &matcher)).to(be_ok());
-        expect!(Value::String("100".into()).matches_with(Value::String("101".into()), &matcher)).to(be_ok());
-        expect!(Value::String("100".into()).matches_with(Value::String("10a".into()), &matcher)).to(be_err());
-        expect!(Value::String("100".into()).matches_with(json!(100), &matcher)).to(be_ok());
+        expect!(Value::String("100".into()).matches_with(Value::String("100".into()), &matcher, false)).to(be_ok());
+        expect!(Value::String("100".into()).matches_with(Value::String("101".into()), &matcher, false)).to(be_ok());
+        expect!(Value::String("100".into()).matches_with(Value::String("10a".into()), &matcher, false)).to(be_err());
+        expect!(Value::String("100".into()).matches_with(json!(100), &matcher, false)).to(be_ok());
     }
 
   #[test]
   fn includes_matcher_test() {
     let matcher = MatchingRule::Include("10".into());
-    expect!(Value::String("100".into()).matches_with(Value::String("100".into()), &matcher)).to(be_ok());
-    expect!(Value::String("100".into()).matches_with(Value::String("101".into()), &matcher)).to(be_ok());
-    expect!(Value::String("100".into()).matches_with(Value::String("1a0".into()), &matcher)).to(be_err());
-    expect!(Value::String("100".into()).matches_with(json!(100), &matcher)).to(be_ok());
+    expect!(Value::String("100".into()).matches_with(Value::String("100".into()), &matcher, false)).to(be_ok());
+    expect!(Value::String("100".into()).matches_with(Value::String("101".into()), &matcher, false)).to(be_ok());
+    expect!(Value::String("100".into()).matches_with(Value::String("1a0".into()), &matcher, false)).to(be_err());
+    expect!(Value::String("100".into()).matches_with(json!(100), &matcher, false)).to(be_ok());
   }
 
     #[test]
     fn type_matcher_test() {
         let matcher = MatchingRule::Type;
-        expect!(Value::String("100".into()).matches_with(Value::String("100".into()), &matcher)).to(be_ok());
-        expect!(Value::String("100".into()).matches_with(Value::String("101".into()), &matcher)).to(be_ok());
-        expect!(Value::String("100".into()).matches_with(Value::String("10a".into()), &matcher)).to(be_ok());
-        expect!(Value::String("100".into()).matches_with(json!(100), &matcher)).to(be_err());
+        expect!(Value::String("100".into()).matches_with(Value::String("100".into()), &matcher, false)).to(be_ok());
+        expect!(Value::String("100".into()).matches_with(Value::String("101".into()), &matcher, false)).to(be_ok());
+        expect!(Value::String("100".into()).matches_with(Value::String("10a".into()), &matcher, false)).to(be_ok());
+        expect!(Value::String("100".into()).matches_with(json!(100), &matcher, false)).to(be_err());
     }
 
     #[test]
     fn min_type_matcher_test() {
         let matcher = MatchingRule::MinType(2);
-        expect!(Value::Array(vec![]).matches_with(&Value::Array(vec![json!(100), json!(100)]), &matcher)).to(be_ok());
-        expect!(Value::Array(vec![]).matches_with(&Value::Array(vec![json!(100)]), &matcher)).to(be_err());
-        expect!(Value::String("100".into()).matches_with(&Value::String("101".into()), &matcher)).to(be_ok());
+        expect!(Value::Array(vec![]).matches_with(&Value::Array(vec![json!(100), json!(100)]), &matcher, false)).to(be_ok());
+        expect!(Value::Array(vec![]).matches_with(&Value::Array(vec![json!(100)]), &matcher, false)).to(be_err());
+        expect!(Value::Array(vec![]).matches_with(&Value::Array(vec![json!(100)]), &matcher, true)).to(be_ok());
+        expect!(Value::String("100".into()).matches_with(&Value::String("101".into()), &matcher, false)).to(be_ok());
     }
 
     #[test]
     fn max_type_matcher_test() {
         let matcher = MatchingRule::MaxType(1);
-        expect!(Value::Array(vec![]).matches_with(&Value::Array(vec![json!(100), json!(100)]), &matcher)).to(be_err());
-        expect!(Value::Array(vec![]).matches_with(&Value::Array(vec![json!(100)]), &matcher)).to(be_ok());
-        expect!(Value::String("100".into()).matches_with(&Value::String("101".into()), &matcher)).to(be_ok());
+        expect!(Value::Array(vec![]).matches_with(&Value::Array(vec![json!(100), json!(100)]), &matcher, false)).to(be_err());
+        expect!(Value::Array(vec![]).matches_with(&Value::Array(vec![json!(100), json!(100)]), &matcher, true)).to(be_ok());
+        expect!(Value::Array(vec![]).matches_with(&Value::Array(vec![json!(100)]), &matcher, false)).to(be_ok());
+        expect!(Value::String("100".into()).matches_with(&Value::String("101".into()), &matcher, false)).to(be_ok());
     }
 
     #[test]
     fn min_max_type_matcher_test() {
       let matcher = MatchingRule::MinMaxType(2, 3);
       expect!(Value::Array(vec![]).matches_with(&Value::Array(vec![json!(100), json!(100)]),
-        &matcher)).to(be_ok());
+        &matcher, false)).to(be_ok());
       expect!(Value::Array(vec![]).matches_with(&Value::Array(vec![json!(100), json!(100),
-        json!(100)]), &matcher)).to(be_ok());
+        json!(100)]), &matcher, false)).to(be_ok());
       expect!(Value::Array(vec![]).matches_with(&Value::Array(vec![json!(100), json!(100),
-        json!(100), json!(100)]), &matcher)).to(be_err());
-      expect!(Value::Array(vec![]).matches_with(&Value::Array(vec![json!(100)]), &matcher)).to(be_err());
-      expect!(Value::String("100".into()).matches_with(&Value::String("101".into()), &matcher)).to(be_ok());
+        json!(100), json!(100)]), &matcher, false)).to(be_err());
+      expect!(Value::Array(vec![]).matches_with(&Value::Array(vec![json!(100), json!(100),
+        json!(100), json!(100)]), &matcher, true)).to(be_ok());
+      expect!(Value::Array(vec![]).matches_with(&Value::Array(vec![json!(100)]), &matcher, false)).to(be_err());
+      expect!(Value::String("100".into()).matches_with(&Value::String("101".into()), &matcher, false)).to(be_ok());
     }
 
   #[test]
   fn integer_matcher_test() {
     let matcher = MatchingRule::Integer;
-    expect!(Value::String("100".into()).matches_with(&Value::String("100".into()), &matcher)).to(be_err());
-    expect!(Value::String("100".into()).matches_with(&json!(100), &matcher)).to(be_ok());
-    expect!(Value::String("100".into()).matches_with(&json!(100.02), &matcher)).to(be_err());
+    expect!(Value::String("100".into()).matches_with(&Value::String("100".into()), &matcher, false)).to(be_err());
+    expect!(Value::String("100".into()).matches_with(&json!(100), &matcher, false)).to(be_ok());
+    expect!(Value::String("100".into()).matches_with(&json!(100.02), &matcher, false)).to(be_err());
   }
 
   #[test]
   fn decimal_matcher_test() {
     let matcher = MatchingRule::Decimal;
-    expect!(Value::String("100".into()).matches_with(&Value::String("100".into()), &matcher)).to(be_err());
-    expect!(Value::String("100".into()).matches_with(&json!(100), &matcher)).to(be_err());
-    expect!(Value::String("100".into()).matches_with(&json!(100.01), &matcher)).to(be_ok());
+    expect!(Value::String("100".into()).matches_with(&Value::String("100".into()), &matcher, false)).to(be_err());
+    expect!(Value::String("100".into()).matches_with(&json!(100), &matcher, false)).to(be_err());
+    expect!(Value::String("100".into()).matches_with(&json!(100.01), &matcher, false)).to(be_ok());
   }
 
   #[test]
   fn number_matcher_test() {
     let matcher = MatchingRule::Number;
-    expect!(Value::String("100".into()).matches_with(&Value::String("100".into()), &matcher)).to(be_err());
-    expect!(Value::String("100".into()).matches_with(&json!(100), &matcher)).to(be_ok());
-    expect!(Value::String("100".into()).matches_with(&json!(100.01), &matcher)).to(be_ok());
+    expect!(Value::String("100".into()).matches_with(&Value::String("100".into()), &matcher, false)).to(be_err());
+    expect!(Value::String("100".into()).matches_with(&json!(100), &matcher, false)).to(be_ok());
+    expect!(Value::String("100".into()).matches_with(&json!(100.01), &matcher, false)).to(be_ok());
   }
 
   #[test]
   fn boolean_matcher_test() {
     let matcher = MatchingRule::Boolean;
-    expect!(Value::Bool(true).matches_with(&Value::String("100".into()), &matcher)).to(be_err());
-    expect!(Value::Bool(true).matches_with(&Value::Bool(false), &matcher)).to(be_ok());
-    expect!(Value::Bool(true).matches_with(&json!(100), &matcher)).to(be_err());
-    expect!(Value::Bool(true).matches_with(&Value::String("true".into()), &matcher)).to(be_ok());
-    expect!(Value::Bool(true).matches_with(&Value::String("false".into()), &matcher)).to(be_ok());
+    expect!(Value::Bool(true).matches_with(&Value::String("100".into()), &matcher, false)).to(be_err());
+    expect!(Value::Bool(true).matches_with(&Value::Bool(false), &matcher, false)).to(be_ok());
+    expect!(Value::Bool(true).matches_with(&json!(100), &matcher, false)).to(be_err());
+    expect!(Value::Bool(true).matches_with(&Value::String("true".into()), &matcher, false)).to(be_ok());
+    expect!(Value::Bool(true).matches_with(&Value::String("false".into()), &matcher, false)).to(be_ok());
   }
 
   #[test]
   fn null_matcher_test() {
     let matcher = MatchingRule::Null;
-    expect!(Value::String("100".into()).matches_with(&Value::String("100".into()), &matcher)).to(be_err());
-    expect!(Value::String("100".into()).matches_with(&Value::String("101".into()), &matcher)).to(be_err());
-    expect!(Value::String("100".into()).matches_with(&Value::String("10a".into()), &matcher)).to(be_err());
-    expect!(Value::String("100".into()).matches_with(&json!(100), &matcher)).to(be_err());
-    expect!(Value::String("100".into()).matches_with(&json!(100.2), &matcher)).to(be_err());
-    expect!(Value::String("100".into()).matches_with(&json!("null"), &matcher)).to(be_err());
-    expect!(Value::String("100".into()).matches_with(&Value::Null, &matcher)).to(be_ok());
+    expect!(Value::String("100".into()).matches_with(&Value::String("100".into()), &matcher, false)).to(be_err());
+    expect!(Value::String("100".into()).matches_with(&Value::String("101".into()), &matcher, false)).to(be_err());
+    expect!(Value::String("100".into()).matches_with(&Value::String("10a".into()), &matcher, false)).to(be_err());
+    expect!(Value::String("100".into()).matches_with(&json!(100), &matcher, false)).to(be_err());
+    expect!(Value::String("100".into()).matches_with(&json!(100.2), &matcher, false)).to(be_err());
+    expect!(Value::String("100".into()).matches_with(&json!("null"), &matcher, false)).to(be_err());
+    expect!(Value::String("100".into()).matches_with(&Value::Null, &matcher, false)).to(be_ok());
   }
 
   #[test_env_log::test]
@@ -886,7 +909,9 @@ mod tests {
         "$.articles[*].variants.*.bundles.*.referencedArticles[*]" => [ MatchingRule::Type ]
       }
     };
-    let context = MatchingContext::new(DiffConfig::AllowUnexpectedKeys, &matching_rules.rules_for_category("body").unwrap());
+    let context = MatchingContext::new(DiffConfig::AllowUnexpectedKeys,
+                                       &matching_rules.rules_for_category("body").unwrap(),
+                                       &hashmap!{});
     let result = match_json(&val1, &val2, &context);
     expect!(result).to(be_ok());
   }
@@ -904,7 +929,7 @@ mod tests {
       "body" => {
         "$" => [ MatchingRule::ArrayContains(vec![]) ]
       }
-    }.rules_for_category("body").unwrap()));
+    }.rules_for_category("body").unwrap(), &hashmap!{}));
     expect!(result).to(be_ok());
   }
 
@@ -934,7 +959,7 @@ mod tests {
       "body" => {
         "$" => [ MatchingRule::ArrayContains(vec![]) ]
       }
-    }.rules_for_category("body").unwrap()));
+    }.rules_for_category("body").unwrap(), &hashmap!{}));
     expect!(result).to(be_err().value(vec![
       BodyMismatch {
         path: "$".to_string(),
@@ -1060,7 +1085,7 @@ mod tests {
           }, HashMap::default())])
         ]
       }
-    }.rules_for_category("body").unwrap());
+    }.rules_for_category("body").unwrap(), &hashmap!{});
     let result = match_json(&expected, &actual, &context);
     expect!(result).to(be_ok());
   }
@@ -1071,11 +1096,13 @@ mod tests {
     let expected = expected_json.as_object().unwrap();
     let actual_json = json!({"foo": "bar"});
     let actual = actual_json.as_object().unwrap();
-    let context = MatchingContext::new(DiffConfig::AllowUnexpectedKeys, &MatchingRuleCategory::empty("body"));
+    let context = MatchingContext::new(DiffConfig::AllowUnexpectedKeys,
+                                       &MatchingRuleCategory::empty("body"), &hashmap!{});
     let result = compare_maps(&vec!["$"], expected, actual, &context);
     expect!(result).to(be_ok());
 
-    let context = MatchingContext::new(DiffConfig::NoUnexpectedKeys, &MatchingRuleCategory::empty("body"));
+    let context = MatchingContext::new(DiffConfig::NoUnexpectedKeys,
+                                       &MatchingRuleCategory::empty("body"), &hashmap!{});
     let result = compare_maps(&vec!["$"], expected, actual, &context);
     expect!(result).to(be_err());
   }
