@@ -45,7 +45,7 @@ fn match_status_using_matchers() {
   };
   let context = MatchingContext::new(
     DiffConfig::AllowUnexpectedKeys,
-    &rules
+    &rules, &hashmap!{}
   );
   expect!(match_status(200, 204, &context)).to(be_ok());
   let result = match_status(200, 500, &context);
@@ -75,7 +75,7 @@ fn match_query_applies_matching_rules_when_param_has_an_underscore() {
   };
   let context = MatchingContext::new(
     DiffConfig::AllowUnexpectedKeys,
-    &rules.rules_for_category("query").unwrap_or_default()
+    &rules.rules_for_category("query").unwrap_or_default(), &hashmap!{}
   );
   let result = match_query(Some(expected), Some(actual), &context);
   expect!(result.values().flatten()).to(be_empty());
@@ -222,14 +222,14 @@ fn match_query_returns_a_mismatch_if_the_values_are_not_the_same() {
   });
 }
 
-#[test]
-fn body_does_not_match_if_different_content_types() {
+#[tokio::test]
+async fn body_does_not_match_if_different_content_types() {
   let expected = Request {
     method: s!("GET"),
     path: s!("/"),
     query: None,
     headers: Some(hashmap! { s!("Content-Type") => vec![s!("application/json")] }),
-    body: OptionalBody::Present(Bytes::new(), None),
+    body: OptionalBody::Present(Bytes::new(), None, None),
     ..Request::default()
   };
   let actual = Request {
@@ -241,7 +241,7 @@ fn body_does_not_match_if_different_content_types() {
     ..Request::default()
   };
   let result = match_body(&expected, &actual, &MatchingContext::default(),
-                          &MatchingContext::default());
+                          &MatchingContext::default()).await;
   let mismatches = result.mismatches();
   expect!(mismatches.iter()).to_not(be_empty());
   expect!(mismatches[0].clone()).to(be_equal_to(Mismatch::BodyTypeMismatch {
@@ -253,14 +253,14 @@ fn body_does_not_match_if_different_content_types() {
   }));
 }
 
-#[test]
-fn body_matching_uses_any_matcher_for_content_type_header() {
+#[tokio::test]
+async fn body_matching_uses_any_matcher_for_content_type_header() {
   let expected = Request {
     method: s!("GET"),
     path: s!("/"),
     query: None,
     headers: Some(hashmap! { s!("Content-Type") => vec![s!("application/json")] }),
-    body: OptionalBody::Present(Bytes::from("100"), None),
+    body: OptionalBody::Present(Bytes::from("100"), None, None),
     ..Request::default()
   };
   let actual = Request {
@@ -268,22 +268,22 @@ fn body_matching_uses_any_matcher_for_content_type_header() {
     path: s!("/"),
     query: None,
     headers: Some(hashmap! { s!("Content-Type") => vec![s!("application/hal+json")] }),
-    body: OptionalBody::Present(Bytes::from("100"), None),
+    body: OptionalBody::Present(Bytes::from("100"), None, None),
     ..Request::default()
   };
   let header_context = MatchingContext::new(
     DiffConfig::AllowUnexpectedKeys,
     &matchingrules! {
         "header" => { "Content-Type" => [ MatchingRule::Regex("application/.*json".into()) ] }
-    }.rules_for_category("header").unwrap_or_default()
+    }.rules_for_category("header").unwrap_or_default(), &hashmap!{}
   );
-  let result = match_body(&expected, &actual, &MatchingContext::default(), &header_context);
+  let result = match_body(&expected, &actual, &MatchingContext::default(), &header_context).await;
   let mismatches = result.mismatches();
   expect!(mismatches.iter()).to(be_empty());
 }
 
-#[test]
-fn body_matches_if_expected_is_missing() {
+#[tokio::test]
+async fn body_matches_if_expected_is_missing() {
   let expected = Request {
     method: s!("GET"),
     path: s!("/"),
@@ -297,21 +297,21 @@ fn body_matches_if_expected_is_missing() {
     path: s!("/"),
     query: None,
     headers: Some(hashmap! { s!("Content-Type") => vec![s!("application/json")] }),
-    body: OptionalBody::Present("{}".into(), None),
+    body: OptionalBody::Present("{}".into(), None, None),
     ..Request::default()
   };
-  let result = match_body(&expected, &actual, &MatchingContext::default(), &MatchingContext::default());
+  let result = match_body(&expected, &actual, &MatchingContext::default(), &MatchingContext::default()).await;
   expect!(result.mismatches().iter()).to(be_empty());
 }
 
-#[test]
-fn body_matches_with_extended_mime_types() {
+#[tokio::test]
+async fn body_matches_with_extended_mime_types() {
   let expected = Request {
     method: s!("GET"),
     path: s!("/"),
     query: None,
     headers: Some(hashmap! { s!("Content-Type") => vec![s!("application/thrift+json")] }),
-    body: OptionalBody::Present(r#"{"test":true}"#.into(), None),
+    body: OptionalBody::Present(r#"{"test":true}"#.into(), None, None),
     ..Request::default()
   };
   let actual = Request {
@@ -319,10 +319,10 @@ fn body_matches_with_extended_mime_types() {
     path: s!("/"),
     query: None,
     headers: Some(hashmap! { s!("Content-Type") => vec![s!("application/thrift+json")] }),
-    body: OptionalBody::Present(r#"{"test": true}"#.into(), None),
+    body: OptionalBody::Present(r#"{"test": true}"#.into(), None, None),
     ..Request::default()
   };
-  let result = match_body(&expected, &actual, &MatchingContext::default(), &MatchingContext::default());
+  let result = match_body(&expected, &actual, &MatchingContext::default(), &MatchingContext::default()).await;
   expect!(result.mismatches().iter()).to(be_empty());
 }
 
@@ -488,7 +488,7 @@ fn match_path_returns_nothing_if_the_path_matches_with_a_matcher() {
     DiffConfig::AllowUnexpectedKeys,
     &matchingrules! {
         "path" => { "" => [ MatchingRule::Regex(s!("/path/\\d+")) ] }
-    }.rules_for_category("path").unwrap_or_default()
+    }.rules_for_category("path").unwrap_or_default(), &hashmap!{}
   );
   let result = match_path(&"/path/1234".to_string(), &"/path/5678".to_string(), &context);
   expect!(result).to(be_ok());
@@ -500,7 +500,7 @@ fn match_path_returns_a_mismatch_if_the_path_does_not_match_with_a_matcher() {
     DiffConfig::AllowUnexpectedKeys,
     &matchingrules! {
         "path" => { "" => [ MatchingRule::Regex(s!("/path/\\d+")) ] }
-    }.rules_for_category("path").unwrap_or_default()
+    }.rules_for_category("path").unwrap_or_default(), &hashmap!{}
   );
   let result = match_path(&"/path/1234".to_string(), &"/path/abc".to_string(), &context);
   expect!(result).to(be_err().value(vec![ Mismatch::PathMismatch {
@@ -518,7 +518,7 @@ fn match_query_returns_no_mismatch_if_the_values_are_not_the_same_but_match_by_a
       "query" => {
         "a" => [ MatchingRule::Regex(s!("\\w+")) ]
       }
-    }.rules_for_category("query").unwrap_or_default()
+    }.rules_for_category("query").unwrap_or_default(), &hashmap!{}
   );
   let mut query_map = HashMap::new();
   query_map.insert(s!("a"), vec![s!("b")]);
@@ -538,7 +538,7 @@ fn match_query_returns_a_mismatch_if_the_values_do_not_match_by_a_matcher() {
       "query" => {
         "a" => [ MatchingRule::Regex(s!("\\d+")) ]
       }
-    }.rules_for_category("query").unwrap_or_default()
+    }.rules_for_category("query").unwrap_or_default(), &hashmap!{}
   );
   let mut query_map = HashMap::new();
   query_map.insert(s!("a"), vec![s!("b")]);
@@ -557,24 +557,24 @@ fn match_query_returns_a_mismatch_if_the_values_do_not_match_by_a_matcher() {
 }
 
 macro_rules! request {
-  ($e:expr) => (Request { body: OptionalBody::Present($e.into(), None), .. Request::default() })
+  ($e:expr) => (Request { body: OptionalBody::Present($e.into(), None, None), .. Request::default() })
 }
 
-#[test]
-fn matching_text_body_be_true_when_bodies_are_equal() {
+#[tokio::test]
+async fn matching_text_body_be_true_when_bodies_are_equal() {
   let expected = request!("body value");
   let actual = request!("body value");
   let mismatches = compare_bodies(&TEXT.clone(), &expected, &actual,
-    &MatchingContext::with_config(DiffConfig::AllowUnexpectedKeys));
+    &MatchingContext::with_config(DiffConfig::AllowUnexpectedKeys)).await;
   expect!(mismatches.mismatches().iter()).to(be_empty());
 }
 
-#[test]
-fn matching_text_body_be_false_when_bodies_are_not_equal() {
+#[tokio::test]
+async fn matching_text_body_be_false_when_bodies_are_not_equal() {
   let expected = request!("expected body value");
   let actual = request!("actual body value");
   let mismatches = compare_bodies(&TEXT.clone(), &expected, &actual,
-    &MatchingContext::with_config(DiffConfig::AllowUnexpectedKeys)).mismatches();
+    &MatchingContext::with_config(DiffConfig::AllowUnexpectedKeys)).await.mismatches();
   expect!(mismatches.iter()).to_not(be_empty());
   assert_eq!(mismatches[0], Mismatch::BodyMismatch {
     path: s!("$"),
@@ -584,8 +584,8 @@ fn matching_text_body_be_false_when_bodies_are_not_equal() {
   });
 }
 
-#[test]
-fn matching_text_body_must_use_defined_matcher() {
+#[tokio::test]
+async fn matching_text_body_must_use_defined_matcher() {
   let expected = request!("expected body value");
   let actual = request!("actualbodyvalue");
 
@@ -595,9 +595,9 @@ fn matching_text_body_must_use_defined_matcher() {
       "body" => {
         "$" => [ MatchingRule::Regex(s!("\\w+")) ]
       }
-    }.rules_for_category("body").unwrap_or_default()
+    }.rules_for_category("body").unwrap_or_default(), &hashmap!{}
   );
-  let mismatches = compare_bodies(&TEXT.clone(), &expected, &actual, &context);
+  let mismatches = compare_bodies(&TEXT.clone(), &expected, &actual, &context).await;
   expect!(mismatches.mismatches().iter()).to(be_empty());
 
   let context = MatchingContext::new(
@@ -606,9 +606,9 @@ fn matching_text_body_must_use_defined_matcher() {
       "body" => {
         "$" => [ MatchingRule::Regex(s!("\\d+")) ]
       }
-    }.rules_for_category("body").unwrap_or_default()
+    }.rules_for_category("body").unwrap_or_default(), &hashmap!{}
   );
-  let mismatches = compare_bodies(&TEXT.clone(), &expected, &actual, &context);
+  let mismatches = compare_bodies(&TEXT.clone(), &expected, &actual, &context).await;
   expect!(mismatches.mismatches().iter()).to_not(be_empty());
 }
 
@@ -625,7 +625,7 @@ fn values_matcher_defined() {
         "$.x[*].y" => [ MatchingRule::Values ],
         "$.y[*].y" => [ MatchingRule::Type ]
       }
-    }.rules_for_category("body").unwrap());
+    }.rules_for_category("body").unwrap(), &hashmap!{});
 
   expect!(context.values_matcher_defined(&["$"])).to(be_true());
   expect!(context.values_matcher_defined(&["$", "x"])).to(be_false());
