@@ -1,4 +1,4 @@
-use std::collections::btree_map::BTreeMap;
+use std::collections::btree_map::{BTreeMap, Entry};
 
 use anyhow::anyhow;
 use bytes::Bytes;
@@ -26,30 +26,24 @@ pub fn match_xml(expected: &dyn HttpPart, actual: &dyn HttpPart, context: &Match
     (OptionalBody::Missing, _) => (),
     (OptionalBody::Empty, _) => (),
     (OptionalBody::Null, _) => (),
-    (OptionalBody::Present(expected_body, _), OptionalBody::Present(actual_body, _)) => {
+    (OptionalBody::Present(expected_body, _, _), OptionalBody::Present(actual_body, _, _)) => {
       let expected_result = parse_bytes(expected_body);
       let actual_result = parse_bytes(actual_body);
 
       if expected_result.is_err() || actual_result.is_err() {
-        match expected_result {
-          Err(e) => {
-            mismatches.push(Mismatch::BodyMismatch {
-              path: "$".to_string(),
-              expected: expected.body().value(),
-              actual: actual.body().value(),
-              mismatch: format!("Failed to parse the expected body: '{:?}'", e)});
-          },
-          _ => ()
+        if let Err(e) = expected_result {
+          mismatches.push(Mismatch::BodyMismatch {
+            path: "$".to_string(),
+            expected: expected.body().value(),
+            actual: actual.body().value(),
+            mismatch: format!("Failed to parse the expected body: '{:?}'", e)});
         }
-        match actual_result {
-          Err(e) => {
-            mismatches.push(Mismatch::BodyMismatch {
-              path: "$".to_string(),
-              expected: expected.body().value(),
-              actual: actual.body().value(),
-              mismatch: format!("Failed to parse the actual body: '{:?}'", e)});
-          },
-          _ => ()
+        if let Err(e) = actual_result {
+          mismatches.push(Mismatch::BodyMismatch {
+            path: "$".to_string(),
+            expected: expected.body().value(),
+            actual: actual.body().value(),
+            mismatch: format!("Failed to parse the actual body: '{:?}'", e)});
         }
       } else {
         let expected_package = expected_result.unwrap();
@@ -61,7 +55,7 @@ pub fn match_xml(expected: &dyn HttpPart, actual: &dyn HttpPart, context: &Match
         let element = expected_root_node.unwrap().element().unwrap();
         let name = name(element.name());
         let path = vec!["$", name.as_str()];
-        compare_element(&path, &element, &actual_root_node.unwrap().element().unwrap(), &mut mismatches, &context);
+        compare_element(&path, &element, &actual_root_node.unwrap().element().unwrap(), &mut mismatches, context);
       }
     },
     _ => {
@@ -90,7 +84,7 @@ fn name(name: QName) -> String {
 }
 
 impl<'a> Matches<&'a Element<'a>> for &'a Element<'a> {
-    fn matches_with(&self, actual: &Element, matcher: &MatchingRule) -> anyhow::Result<()> {
+    fn matches_with(&self, actual: &Element, matcher: &MatchingRule, cascaded: bool) -> anyhow::Result<()> {
         let result = match *matcher {
           MatchingRule::Regex(ref regex) => {
             match Regex::new(regex) {
@@ -110,19 +104,19 @@ impl<'a> Matches<&'a Element<'a>> for &'a Element<'a> {
              Err(anyhow!("Expected '{}' to be the same type as '{}'", name(self.name()),
                          name(actual.name())))
           },
-          MatchingRule::MinType(min) => if actual.children().len() < min {
+          MatchingRule::MinType(min) => if !cascaded && actual.children().len() < min {
              Err(anyhow!("Expected '{}' to have at least {} children", name(actual.name()), min))
           } else {
              Ok(())
           },
-          MatchingRule::MaxType(max) => if actual.children().len() > max {
+          MatchingRule::MaxType(max) => if !cascaded && actual.children().len() > max {
              Err(anyhow!("Expected '{}' to have at most {} children", name(actual.name()), max))
           } else {
              Ok(())
           },
-          MatchingRule::MinMaxType(min, max) => if actual.children().len() < min {
+          MatchingRule::MinMaxType(min, max) => if !cascaded && actual.children().len() < min {
             Err(anyhow!("Expected '{}' to have at least {} children", name(actual.name()), min))
-          } else if actual.children().len() > max {
+          } else if !cascaded && actual.children().len() > max {
             Err(anyhow!("Expected '{}' to have at most {} children", name(actual.name()), max))
           } else {
             Ok(())
@@ -134,6 +128,11 @@ impl<'a> Matches<&'a Element<'a>> for &'a Element<'a> {
                   Err(anyhow!("Expected '{}' to be equal to '{}'", name(self.name()), name(actual.name())))
              }
           },
+          MatchingRule::NotEmpty => if actual.children().is_empty() {
+            Err(anyhow!("Expected '{}' to have at least one child", name(actual.name())))
+          } else {
+            Ok(())
+          },
           _ => Err(anyhow!("Unable to match {:?} using {:?}", self, matcher))
         };
         debug!("Comparing '{:?}' to '{:?}' using {:?} -> {:?}", self, actual, matcher, result);
@@ -141,9 +140,9 @@ impl<'a> Matches<&'a Element<'a>> for &'a Element<'a> {
     }
 }
 
-fn path_to_string(path: &Vec<&str>) -> String {
+fn path_to_string(path: &[&str]) -> String {
   path.iter().enumerate().map(|(i, p)| {
-    if i > 0 && !p.starts_with("[") {
+    if i > 0 && !p.starts_with('[') {
       ".".to_owned() + p
     } else {
       p.to_string()
@@ -151,21 +150,21 @@ fn path_to_string(path: &Vec<&str>) -> String {
   }).collect()
 }
 
-fn compare_element(path: &Vec<&str>, expected: &Element, actual: &Element,
+fn compare_element(path: &[&str], expected: &Element, actual: &Element,
   mismatches: &mut Vec<super::Mismatch>, context: &MatchingContext) {
-  let matcher_result = if context.matcher_is_defined(&path) {
-    log::debug!("calling match_values {:?} on {:?}", path, actual);
-    match_values(&path, context, expected, actual)
+  let matcher_result = if context.matcher_is_defined(path) {
+    debug!("calling match_values {:?} on {:?}", path, actual);
+    match_values(path, context, expected, actual)
   } else {
-    expected.matches_with(actual, &MatchingRule::Equality).map_err(|err| vec![err.to_string()])
+    expected.matches_with(actual, &MatchingRule::Equality, false).map_err(|err| vec![err.to_string()])
   };
-  log::debug!("Comparing '{:?}' to '{:?}' at path '{}' -> {:?}", expected, actual,
-    path_to_string(&path), matcher_result);
+  debug!("Comparing '{:?}' to '{:?}' at path '{}' -> {:?}", expected, actual,
+    path_to_string(path), matcher_result);
   match matcher_result {
     Err(messages) => {
       for message in messages {
         mismatches.push(Mismatch::BodyMismatch {
-          path: path_to_string(&path),
+          path: path_to_string(path),
           expected: Some(name(expected.name()).into()),
           actual: Some(name(actual.name()).into()),
           mismatch: message.clone()
@@ -173,14 +172,14 @@ fn compare_element(path: &Vec<&str>, expected: &Element, actual: &Element,
       }
     },
     Ok(_) => {
-      compare_attributes(&path, expected, actual, mismatches, context);
-      compare_children(&path, expected, actual, mismatches, context);
-      compare_text(&path, expected, actual, mismatches, context);
+      compare_attributes(path, expected, actual, mismatches, context);
+      compare_children(path, expected, actual, mismatches, context);
+      compare_text(path, expected, actual, mismatches, context);
     }
   }
 }
 
-fn compare_attributes(path: &Vec<&str>, expected: &Element, actual: &Element,
+fn compare_attributes(path: &[&str], expected: &Element, actual: &Element,
     mismatches: &mut Vec<super::Mismatch>, context: &MatchingContext) {
     let expected_attributes: BTreeMap<String, String> = expected.attributes()
         .iter().map(|attr| (name(attr.name()), s!(attr.value()))).collect();
@@ -231,16 +230,15 @@ fn compare_attributes(path: &Vec<&str>, expected: &Element, actual: &Element,
 fn children<'a>(element: &Element<'a>) -> Vec<Element<'a>> {
   element.children().iter().cloned()
     .map(|child| child.element())
-    .filter(|child| child.is_some())
-    .map(|child| child.unwrap())
+    .flatten()
     .collect()
 }
 
-fn desc_children(children: &Vec<Element>) -> String {
+fn desc_children(children: &[Element]) -> String {
   children.iter().map(|child| name(child.name())).join(", ")
 }
 
-fn compare_children(path: &Vec<&str>, expected: &Element, actual: &Element,
+fn compare_children(path: &[&str], expected: &Element, actual: &Element,
   mismatches: &mut Vec<super::Mismatch>, context: &MatchingContext) {
   let expected_children = children(expected);
   let actual_children = children(actual);
@@ -256,19 +254,17 @@ fn compare_children(path: &Vec<&str>, expected: &Element, actual: &Element,
     let mut expected_children_by_name: BTreeMap<String, Vec<Element>> = btreemap!{};
     for child in &expected_children {
       let key = name(child.name());
-      if expected_children_by_name.contains_key(&key) {
-        expected_children_by_name.get_mut(&key).unwrap().push(child.clone());
-      } else {
-        expected_children_by_name.insert(key, vec![ child.clone() ]);
+      match expected_children_by_name.entry(key) {
+        Entry::Vacant(e) => { e.insert(vec![ *child ]); },
+        Entry::Occupied(mut e) => e.get_mut().push(*child)
       }
     }
     let mut actual_children_by_name: BTreeMap<String, Vec<Element>> = btreemap!{};
     for child in &actual_children {
       let key = name(child.name());
-      if actual_children_by_name.contains_key(&key) {
-        actual_children_by_name.get_mut(&key).unwrap().push(child.clone());
-      } else {
-        actual_children_by_name.insert(key, vec![ child.clone() ]);
+      match actual_children_by_name.entry(key) {
+        Entry::Vacant(e) => { e.insert(vec![ *child ]); },
+        Entry::Occupied(mut e) => e.get_mut().push(*child)
       }
     }
     for (key, group) in actual_children_by_name {
@@ -276,11 +272,11 @@ fn compare_children(path: &Vec<&str>, expected: &Element, actual: &Element,
       p.push(key.as_str());
       if expected_children_by_name.contains_key(&key) {
         let expected_children = expected_children_by_name.remove(&key).unwrap();
-        let expected = expected_children.iter().next().unwrap();
+        let expected = expected_children.first().unwrap();
         if context.type_matcher_defined(&p) {
           log::debug!("Matcher defined for path {}", path_to_string(&p));
           for child in group {
-            compare_element(&p, &expected, &child, mismatches, context);
+            compare_element(&p, expected, &child, mismatches, context);
           }
         } else {
           for pair in expected_children.iter().zip_longest(group) {
@@ -298,7 +294,7 @@ fn compare_children(path: &Vec<&str>, expected: &Element, actual: &Element,
                   mismatch: format!("Expected child <{}/> but was missing", name(expected.name()))});
               },
               EitherOrBoth::Both(expected, actual) => {
-                compare_element(&p, &expected, &actual, mismatches, context);
+                compare_element(&p, expected, &actual, mismatches, context);
               }
             }
           }
@@ -322,7 +318,7 @@ fn compare_children(path: &Vec<&str>, expected: &Element, actual: &Element,
   }
 }
 
-fn compare_text(path: &Vec<&str>, expected: &Element, actual: &Element,
+fn compare_text(path: &[&str], expected: &Element, actual: &Element,
     mismatches: &mut Vec<super::Mismatch>, context: &MatchingContext) {
     let expected_text = expected.children().iter().cloned()
         .filter(|child| child.text().is_some())
@@ -337,39 +333,36 @@ fn compare_text(path: &Vec<&str>, expected: &Element, actual: &Element,
     let matcher_result = if context.matcher_is_defined(&p) {
       match_values(&p, context, expected_text.trim(), actual_text.trim())
     } else {
-      expected_text.matches_with(actual_text.trim(), &MatchingRule::Equality)
+      expected_text.matches_with(actual_text.trim(), &MatchingRule::Equality, false)
         .map_err(|err| vec![err.to_string()])
     };
     debug!("Comparing text '{}' to '{}' at path '{}' -> {:?}", expected_text, actual_text,
         path_to_string(path), matcher_result);
-    match matcher_result {
-        Err(messages) => {
-          for message in messages {
-            mismatches.push(Mismatch::BodyMismatch {
-              path: path_to_string(path) + ".#text",
-              expected: Some(expected_text.clone().into()),
-              actual: Some(actual_text.clone().into()),
-              mismatch: message.clone()
-            })
-          }
-        },
-        Ok(_) => ()
+    if let Err(messages) = matcher_result {
+      for message in messages {
+        mismatches.push(Mismatch::BodyMismatch {
+          path: path_to_string(path) + ".#text",
+          expected: Some(expected_text.clone().into()),
+          actual: Some(actual_text.clone().into()),
+          mismatch: message.clone()
+        })
+      }
     }
 }
 
-fn compare_value(path: &Vec<&str>, expected: &String, actual: &String, context: &MatchingContext) -> Result<(), Vec<Mismatch>> {
-  let matcher_result = if context.matcher_is_defined(&path) {
-    match_values(path, context, expected.as_str(), actual.as_str())
+fn compare_value(path: &[&str], expected: &str, actual: &str, context: &MatchingContext) -> Result<(), Vec<Mismatch>> {
+  let matcher_result = if context.matcher_is_defined(path) {
+    match_values(path, context, expected, actual)
   } else {
-    expected.matches_with(actual, &MatchingRule::Equality).map_err(|err| vec![err.to_string()])
+    expected.matches_with(actual, &MatchingRule::Equality, false).map_err(|err| vec![err.to_string()])
   };
   debug!("Comparing '{}' to '{}' at path '{}' -> {:?}", expected, actual, path_to_string(path), matcher_result);
   matcher_result.map_err(|messages| {
     messages.iter().map(|message| {
       Mismatch::BodyMismatch {
         path: path_to_string(path),
-        expected: Some(expected.clone().into()),
-        actual: Some(actual.clone().into()),
+        expected: Some(expected.to_string().into()),
+        actual: Some(actual.to_string().into()),
         mismatch: message.clone()
       }
     }).collect()
@@ -396,7 +389,7 @@ mod tests {
 
   macro_rules! request {
     ($e:expr) => (Request {
-        body: OptionalBody::Present(Bytes::from($e), None), .. Request::default()
+        body: OptionalBody::Present(Bytes::from($e), None, None), .. Request::default()
       })
   }
 
@@ -647,7 +640,7 @@ mod tests {
       "body" => {
         "$.foo.*" => [ MatchingRule::Type ]
       }
-    }.rules_for_category("body").unwrap()));
+    }.rules_for_category("body").unwrap(), &hashmap!{}));
     expect!(result).to(be_ok());
   }
 
@@ -795,15 +788,15 @@ mod tests {
     "#);
     let result = match_xml(&expected.clone(), &actual.clone(), &MatchingContext::with_config(DiffConfig::AllowUnexpectedKeys));
     expect!(mismatch_message(&result)).to(be_equal_to(s!("Expected 'hello world' to be equal to 'hello mars'")));
-    expect!(result).to(be_err().value(vec![ Mismatch::BodyMismatch { path: s!("$.foo.#text"),
+    expect!(result).to(be_err().value(vec![ Mismatch::BodyMismatch { path: "$.foo.#text".to_string(),
         expected: Some("hello world".into()),
-        actual: Some("hello mars".into()), mismatch: s!("") } ]));
+        actual: Some("hello mars".into()), mismatch: "".to_string() } ]));
 
     let result = match_xml(&expected, &actual, &MatchingContext::new(DiffConfig::AllowUnexpectedKeys, &matchingrules!{
         "body" => {
             "$.foo['#text']" => [ MatchingRule::Regex(r"[a-z\s]+".into()) ]
         }
-    }.rules_for_category("body").unwrap()));
+    }.rules_for_category("body").unwrap(), &hashmap!{}));
     expect!(result).to(be_ok());
   }
 
@@ -817,15 +810,15 @@ mod tests {
     "#);
     let result = match_xml(&expected.clone(), &actual.clone(), &MatchingContext::with_config(DiffConfig::AllowUnexpectedKeys));
     expect!(mismatch_message(&result)).to(be_equal_to(s!("Expected 'helloworld' to be equal to 'hellomars'")));
-    expect!(result).to(be_err().value(vec![ Mismatch::BodyMismatch { path: s!("$.foo.#text"),
+    expect!(result).to(be_err().value(vec![ Mismatch::BodyMismatch { path: "$.foo.#text".to_string(),
         expected: Some("helloworld".into()),
-        actual: Some("hellomars".into()), mismatch: s!("") } ]));
+        actual: Some("hellomars".into()), mismatch: "".to_string() } ]));
 
     let result = match_xml(&expected, &actual, &MatchingContext::new(DiffConfig::AllowUnexpectedKeys, &matchingrules!{
       "body" => {
-        "$.foo['#text']" => [ MatchingRule::Regex(s!("[a-z]+")) ]
+        "$.foo['#text']" => [ MatchingRule::Regex("[a-z]+".to_string()) ]
       }
-    }.rules_for_category("body").unwrap()));
+    }.rules_for_category("body").unwrap(), &hashmap!{}));
     expect!(result).to(be_ok());
   }
 
@@ -841,7 +834,7 @@ mod tests {
       "body" => {
         "$.foo" => [ MatchingRule::Type ]
       }
-    }.rules_for_category("body").unwrap()));
+    }.rules_for_category("body").unwrap(), &hashmap!{}));
     expect!(result).to(be_ok());
   }
 
@@ -915,7 +908,8 @@ mod tests {
         "$.providerService.attribute1.newattribute2.hiddenData" => [ MatchingRule::Regex("[a-zA-Z0-9]*".into()) ]
       }
     }.rules_for_category("body").unwrap();
-    let result = match_xml(&expected.clone(), &actual.clone(), &MatchingContext::new(DiffConfig::AllowUnexpectedKeys, &rules));
+    let result = match_xml(&expected.clone(), &actual.clone(),
+                           &MatchingContext::new(DiffConfig::AllowUnexpectedKeys, &rules, &hashmap!{}));
     expect!(result).to(be_ok());
   }
 
@@ -1010,7 +1004,7 @@ mod tests {
       "body" => { "$.foo['@urn:ns:something']" => [ MatchingRule::Regex(s!("^[0-9]+$")) ] }
     };
     let result = match_xml(&expected, &actual, &MatchingContext::new(DiffConfig::NoUnexpectedKeys,
-                                                                     &matching_rules.rules_for_category("body").unwrap()));
+                                                                     &matching_rules.rules_for_category("body").unwrap(), &hashmap!{}));
     expect!(result).to(be_ok());
   }
 
@@ -1019,10 +1013,10 @@ mod tests {
     let expected = request!("<ns:foo xmlns:ns=\"urn:ns\"><ns:something>101</ns:something></ns:foo>");
     let actual = request!("<ns:foo xmlns:ns=\"urn:ns\"><ns:something>100</ns:something></ns:foo>");
     let matching_rules = matchingrules! {
-      "body" => { "$['urn:ns:foo']['urn:ns:something'].#text" => [ MatchingRule::Regex(s!("^[0-9]+$")) ] }
+      "body" => { "$['urn:ns:foo']['urn:ns:something'].#text" => [ MatchingRule::Regex("^[0-9]+$".to_string()) ] }
     };
     let result = match_xml(&expected, &actual, &MatchingContext::new(DiffConfig::NoUnexpectedKeys,
-      &matching_rules.rules_for_category("body").unwrap()));
+      &matching_rules.rules_for_category("body").unwrap(), &hashmap!{}));
     expect!(result).to(be_ok());
   }
 
@@ -1113,7 +1107,8 @@ mod tests {
         "$.animals.*['@id']" => [ MatchingRule::Integer ]
       }
     }.rules_for_category("body").unwrap();
-    let result = match_xml(&expected.clone(), &actual.clone(), &MatchingContext::new(DiffConfig::NoUnexpectedKeys, &matching_rules));
+    let result = match_xml(&expected.clone(), &actual.clone(),
+                           &MatchingContext::new(DiffConfig::NoUnexpectedKeys, &matching_rules, &hashmap!{}));
     expect!(result).to(be_ok());
   }
 
@@ -1131,7 +1126,8 @@ mod tests {
         "$.foo['@somethingElse']" => [ MatchingRule::Boolean ]
       }
     }.rules_for_category("body").unwrap();
-    let result = match_xml(&expected.clone(), &actual.clone(), &MatchingContext::new(DiffConfig::NoUnexpectedKeys, &matching_rules));
+    let result = match_xml(&expected.clone(), &actual.clone(),
+                           &MatchingContext::new(DiffConfig::NoUnexpectedKeys, &matching_rules, &hashmap!{}));
     expect!(mismatch_message(&result)).to(be_equal_to("Expected \'101\' to match a boolean".to_string()));
     expect!(result).to(be_err().value(vec![
       Mismatch::BodyMismatch {
