@@ -7,12 +7,16 @@ use serde_json;
 #[allow(unused_imports)]
 use expectest::prelude::*;
 #[allow(unused_imports)]
+use pact_plugin_driver::catalogue_manager::register_core_entries;
+#[allow(unused_imports)]
 use pact_models::interaction::{Interaction, http_interaction_from_json};
 #[allow(unused_imports)]
 use pact_matching::{match_interaction_request, match_interaction_response};
+#[allow(unused_imports)]
+use pact_models::prelude::{Pact, RequestResponsePact};
 
-#[test]
-fn unexpected_index_with_not_null_value() {
+#[tokio::test]
+async fn unexpected_index_with_not_null_value() {
     println!("FILE: tests/spec_testcases/v1/request/body/unexpected index with not null value.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -53,7 +57,11 @@ fn unexpected_index_with_not_null_value() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().request.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_request(expected, actual, &PactSpecification::V1).unwrap().mismatches();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_request(expected, actual, pact, &PactSpecification::V1).await.unwrap().mismatches();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -62,8 +70,8 @@ fn unexpected_index_with_not_null_value() {
     }
 }
 
-#[test]
-fn unexpected_key_with_null_value() {
+#[tokio::test]
+async fn unexpected_key_with_null_value() {
     println!("FILE: tests/spec_testcases/v1/request/body/unexpected key with null value.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -105,7 +113,11 @@ fn unexpected_key_with_null_value() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().request.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_request(expected, actual, &PactSpecification::V1).unwrap().mismatches();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_request(expected, actual, pact, &PactSpecification::V1).await.unwrap().mismatches();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -114,8 +126,8 @@ fn unexpected_key_with_null_value() {
     }
 }
 
-#[test]
-fn different_value_found_at_key() {
+#[tokio::test]
+async fn different_value_found_at_key() {
     println!("FILE: tests/spec_testcases/v1/request/body/different value found at key.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -156,7 +168,11 @@ fn different_value_found_at_key() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().request.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_request(expected, actual, &PactSpecification::V1).unwrap().mismatches();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_request(expected, actual, pact, &PactSpecification::V1).await.unwrap().mismatches();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -165,8 +181,8 @@ fn different_value_found_at_key() {
     }
 }
 
-#[test]
-fn not_null_found_at_key_when_null_expected() {
+#[tokio::test]
+async fn not_null_found_at_key_when_null_expected() {
     println!("FILE: tests/spec_testcases/v1/request/body/not null found at key when null expected.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -207,7 +223,11 @@ fn not_null_found_at_key_when_null_expected() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().request.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_request(expected, actual, &PactSpecification::V1).unwrap().mismatches();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_request(expected, actual, pact, &PactSpecification::V1).await.unwrap().mismatches();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -216,8 +236,8 @@ fn not_null_found_at_key_when_null_expected() {
     }
 }
 
-#[test]
-fn number_found_in_array_when_string_expected() {
+#[tokio::test]
+async fn number_found_in_array_when_string_expected() {
     println!("FILE: tests/spec_testcases/v1/request/body/number found in array when string expected.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -258,7 +278,11 @@ fn number_found_in_array_when_string_expected() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().request.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_request(expected, actual, &PactSpecification::V1).unwrap().mismatches();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_request(expected, actual, pact, &PactSpecification::V1).await.unwrap().mismatches();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -267,8 +291,8 @@ fn number_found_in_array_when_string_expected() {
     }
 }
 
-#[test]
-fn array_in_different_order() {
+#[tokio::test]
+async fn array_in_different_order() {
     println!("FILE: tests/spec_testcases/v1/request/body/array in different order.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -309,7 +333,11 @@ fn array_in_different_order() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().request.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_request(expected, actual, &PactSpecification::V1).unwrap().mismatches();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_request(expected, actual, pact, &PactSpecification::V1).await.unwrap().mismatches();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -318,8 +346,8 @@ fn array_in_different_order() {
     }
 }
 
-#[test]
-fn plain_text_that_matches() {
+#[tokio::test]
+async fn plain_text_that_matches() {
     println!("FILE: tests/spec_testcases/v1/request/body/plain text that matches.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -352,7 +380,11 @@ fn plain_text_that_matches() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().request.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_request(expected, actual, &PactSpecification::V1).unwrap().mismatches();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_request(expected, actual, pact, &PactSpecification::V1).await.unwrap().mismatches();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -361,8 +393,8 @@ fn plain_text_that_matches() {
     }
 }
 
-#[test]
-fn string_found_in_array_when_number_expected() {
+#[tokio::test]
+async fn string_found_in_array_when_number_expected() {
     println!("FILE: tests/spec_testcases/v1/request/body/string found in array when number expected.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -403,7 +435,11 @@ fn string_found_in_array_when_number_expected() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().request.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_request(expected, actual, &PactSpecification::V1).unwrap().mismatches();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_request(expected, actual, pact, &PactSpecification::V1).await.unwrap().mismatches();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -412,8 +448,8 @@ fn string_found_in_array_when_number_expected() {
     }
 }
 
-#[test]
-fn not_null_found_in_array_when_null_expected() {
+#[tokio::test]
+async fn not_null_found_in_array_when_null_expected() {
     println!("FILE: tests/spec_testcases/v1/request/body/not null found in array when null expected.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -454,7 +490,11 @@ fn not_null_found_in_array_when_null_expected() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().request.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_request(expected, actual, &PactSpecification::V1).unwrap().mismatches();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_request(expected, actual, pact, &PactSpecification::V1).await.unwrap().mismatches();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -463,8 +503,8 @@ fn not_null_found_in_array_when_null_expected() {
     }
 }
 
-#[test]
-fn different_value_found_at_index() {
+#[tokio::test]
+async fn different_value_found_at_index() {
     println!("FILE: tests/spec_testcases/v1/request/body/different value found at index.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -505,7 +545,11 @@ fn different_value_found_at_index() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().request.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_request(expected, actual, &PactSpecification::V1).unwrap().mismatches();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_request(expected, actual, pact, &PactSpecification::V1).await.unwrap().mismatches();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -514,8 +558,8 @@ fn different_value_found_at_index() {
     }
 }
 
-#[test]
-fn number_found_at_key_when_string_expected() {
+#[tokio::test]
+async fn number_found_at_key_when_string_expected() {
     println!("FILE: tests/spec_testcases/v1/request/body/number found at key when string expected.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -556,7 +600,11 @@ fn number_found_at_key_when_string_expected() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().request.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_request(expected, actual, &PactSpecification::V1).unwrap().mismatches();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_request(expected, actual, pact, &PactSpecification::V1).await.unwrap().mismatches();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -565,8 +613,8 @@ fn number_found_at_key_when_string_expected() {
     }
 }
 
-#[test]
-fn missing_index() {
+#[tokio::test]
+async fn missing_index() {
     println!("FILE: tests/spec_testcases/v1/request/body/missing index.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -607,7 +655,11 @@ fn missing_index() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().request.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_request(expected, actual, &PactSpecification::V1).unwrap().mismatches();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_request(expected, actual, pact, &PactSpecification::V1).await.unwrap().mismatches();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -616,8 +668,8 @@ fn missing_index() {
     }
 }
 
-#[test]
-fn null_found_in_array_when_not_null_expected() {
+#[tokio::test]
+async fn null_found_in_array_when_not_null_expected() {
     println!("FILE: tests/spec_testcases/v1/request/body/null found in array when not null expected.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -658,7 +710,11 @@ fn null_found_in_array_when_not_null_expected() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().request.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_request(expected, actual, &PactSpecification::V1).unwrap().mismatches();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_request(expected, actual, pact, &PactSpecification::V1).await.unwrap().mismatches();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -667,8 +723,8 @@ fn null_found_in_array_when_not_null_expected() {
     }
 }
 
-#[test]
-fn unexpected_index_with_null_value() {
+#[tokio::test]
+async fn unexpected_index_with_null_value() {
     println!("FILE: tests/spec_testcases/v1/request/body/unexpected index with null value.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -709,7 +765,11 @@ fn unexpected_index_with_null_value() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().request.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_request(expected, actual, &PactSpecification::V1).unwrap().mismatches();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_request(expected, actual, pact, &PactSpecification::V1).await.unwrap().mismatches();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -718,8 +778,8 @@ fn unexpected_index_with_null_value() {
     }
 }
 
-#[test]
-fn unexpected_key_with_not_null_value() {
+#[tokio::test]
+async fn unexpected_key_with_not_null_value() {
     println!("FILE: tests/spec_testcases/v1/request/body/unexpected key with not null value.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -761,7 +821,11 @@ fn unexpected_key_with_not_null_value() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().request.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_request(expected, actual, &PactSpecification::V1).unwrap().mismatches();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_request(expected, actual, pact, &PactSpecification::V1).await.unwrap().mismatches();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -770,8 +834,8 @@ fn unexpected_key_with_not_null_value() {
     }
 }
 
-#[test]
-fn string_found_at_key_when_number_expected() {
+#[tokio::test]
+async fn string_found_at_key_when_number_expected() {
     println!("FILE: tests/spec_testcases/v1/request/body/string found at key when number expected.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -812,7 +876,11 @@ fn string_found_at_key_when_number_expected() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().request.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_request(expected, actual, &PactSpecification::V1).unwrap().mismatches();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_request(expected, actual, pact, &PactSpecification::V1).await.unwrap().mismatches();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -821,8 +889,8 @@ fn string_found_at_key_when_number_expected() {
     }
 }
 
-#[test]
-fn missing_key() {
+#[tokio::test]
+async fn missing_key() {
     println!("FILE: tests/spec_testcases/v1/request/body/missing key.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -864,7 +932,11 @@ fn missing_key() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().request.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_request(expected, actual, &PactSpecification::V1).unwrap().mismatches();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_request(expected, actual, pact, &PactSpecification::V1).await.unwrap().mismatches();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -873,8 +945,8 @@ fn missing_key() {
     }
 }
 
-#[test]
-fn matches() {
+#[tokio::test]
+async fn matches() {
     println!("FILE: tests/spec_testcases/v1/request/body/matches.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -919,7 +991,11 @@ fn matches() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().request.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_request(expected, actual, &PactSpecification::V1).unwrap().mismatches();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_request(expected, actual, pact, &PactSpecification::V1).await.unwrap().mismatches();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -928,8 +1004,8 @@ fn matches() {
     }
 }
 
-#[test]
-fn null_found_at_key_where_not_null_expected() {
+#[tokio::test]
+async fn null_found_at_key_where_not_null_expected() {
     println!("FILE: tests/spec_testcases/v1/request/body/null found at key where not null expected.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -970,7 +1046,11 @@ fn null_found_at_key_where_not_null_expected() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().request.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_request(expected, actual, &PactSpecification::V1).unwrap().mismatches();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_request(expected, actual, pact, &PactSpecification::V1).await.unwrap().mismatches();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -979,8 +1059,8 @@ fn null_found_at_key_where_not_null_expected() {
     }
 }
 
-#[test]
-fn plain_text_that_does_not_match() {
+#[tokio::test]
+async fn plain_text_that_does_not_match() {
     println!("FILE: tests/spec_testcases/v1/request/body/plain text that does not match.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -1013,7 +1093,11 @@ fn plain_text_that_does_not_match() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().request.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_request(expected, actual, &PactSpecification::V1).unwrap().mismatches();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_request(expected, actual, pact, &PactSpecification::V1).await.unwrap().mismatches();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
