@@ -7,12 +7,16 @@ use serde_json;
 #[allow(unused_imports)]
 use expectest::prelude::*;
 #[allow(unused_imports)]
+use pact_plugin_driver::catalogue_manager::register_core_entries;
+#[allow(unused_imports)]
 use pact_models::interaction::{Interaction, http_interaction_from_json};
 #[allow(unused_imports)]
 use pact_matching::{match_interaction_request, match_interaction_response};
+#[allow(unused_imports)]
+use pact_models::prelude::{Pact, RequestResponsePact};
 
-#[test]
-fn unexpected_index_with_not_null_value() {
+#[tokio::test]
+async fn unexpected_index_with_not_null_value() {
     println!("FILE: tests/spec_testcases/v1/response/body/unexpected index with not null value.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -47,7 +51,11 @@ fn unexpected_index_with_not_null_value() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().response.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_response(expected, actual, &PactSpecification::V1).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_response(expected, actual, pact, &PactSpecification::V1).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -56,8 +64,8 @@ fn unexpected_index_with_not_null_value() {
     }
 }
 
-#[test]
-fn unexpected_key_with_null_value() {
+#[tokio::test]
+async fn unexpected_key_with_null_value() {
     println!("FILE: tests/spec_testcases/v1/response/body/unexpected key with null value.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -93,7 +101,11 @@ fn unexpected_key_with_null_value() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().response.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_response(expected, actual, &PactSpecification::V1).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_response(expected, actual, pact, &PactSpecification::V1).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -102,8 +114,8 @@ fn unexpected_key_with_null_value() {
     }
 }
 
-#[test]
-fn different_value_found_at_key() {
+#[tokio::test]
+async fn different_value_found_at_key() {
     println!("FILE: tests/spec_testcases/v1/response/body/different value found at key.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -138,7 +150,11 @@ fn different_value_found_at_key() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().response.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_response(expected, actual, &PactSpecification::V1).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_response(expected, actual, pact, &PactSpecification::V1).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -147,8 +163,8 @@ fn different_value_found_at_key() {
     }
 }
 
-#[test]
-fn not_null_found_at_key_when_null_expected() {
+#[tokio::test]
+async fn not_null_found_at_key_when_null_expected() {
     println!("FILE: tests/spec_testcases/v1/response/body/not null found at key when null expected.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -183,7 +199,11 @@ fn not_null_found_at_key_when_null_expected() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().response.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_response(expected, actual, &PactSpecification::V1).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_response(expected, actual, pact, &PactSpecification::V1).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -192,8 +212,8 @@ fn not_null_found_at_key_when_null_expected() {
     }
 }
 
-#[test]
-fn number_found_in_array_when_string_expected() {
+#[tokio::test]
+async fn number_found_in_array_when_string_expected() {
     println!("FILE: tests/spec_testcases/v1/response/body/number found in array when string expected.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -228,7 +248,11 @@ fn number_found_in_array_when_string_expected() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().response.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_response(expected, actual, &PactSpecification::V1).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_response(expected, actual, pact, &PactSpecification::V1).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -237,8 +261,8 @@ fn number_found_in_array_when_string_expected() {
     }
 }
 
-#[test]
-fn property_name_is_different_case() {
+#[tokio::test]
+async fn property_name_is_different_case() {
     println!("FILE: tests/spec_testcases/v1/response/body/property name is different case.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -273,7 +297,11 @@ fn property_name_is_different_case() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().response.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_response(expected, actual, &PactSpecification::V1).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_response(expected, actual, pact, &PactSpecification::V1).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -282,8 +310,8 @@ fn property_name_is_different_case() {
     }
 }
 
-#[test]
-fn array_in_different_order() {
+#[tokio::test]
+async fn array_in_different_order() {
     println!("FILE: tests/spec_testcases/v1/response/body/array in different order.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -318,7 +346,11 @@ fn array_in_different_order() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().response.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_response(expected, actual, &PactSpecification::V1).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_response(expected, actual, pact, &PactSpecification::V1).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -327,8 +359,8 @@ fn array_in_different_order() {
     }
 }
 
-#[test]
-fn plain_text_that_matches() {
+#[tokio::test]
+async fn plain_text_that_matches() {
     println!("FILE: tests/spec_testcases/v1/response/body/plain text that matches.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -355,7 +387,11 @@ fn plain_text_that_matches() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().response.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_response(expected, actual, &PactSpecification::V1).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_response(expected, actual, pact, &PactSpecification::V1).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -364,8 +400,8 @@ fn plain_text_that_matches() {
     }
 }
 
-#[test]
-fn string_found_in_array_when_number_expected() {
+#[tokio::test]
+async fn string_found_in_array_when_number_expected() {
     println!("FILE: tests/spec_testcases/v1/response/body/string found in array when number expected.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -400,7 +436,11 @@ fn string_found_in_array_when_number_expected() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().response.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_response(expected, actual, &PactSpecification::V1).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_response(expected, actual, pact, &PactSpecification::V1).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -409,8 +449,8 @@ fn string_found_in_array_when_number_expected() {
     }
 }
 
-#[test]
-fn objects_in_array_first_matches() {
+#[tokio::test]
+async fn objects_in_array_first_matches() {
     println!("FILE: tests/spec_testcases/v1/response/body/objects in array first matches.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -444,7 +484,11 @@ fn objects_in_array_first_matches() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().response.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_response(expected, actual, &PactSpecification::V1).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_response(expected, actual, pact, &PactSpecification::V1).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -453,8 +497,8 @@ fn objects_in_array_first_matches() {
     }
 }
 
-#[test]
-fn deeply_nested_objects() {
+#[tokio::test]
+async fn deeply_nested_objects() {
     println!("FILE: tests/spec_testcases/v1/response/body/deeply nested objects.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -511,7 +555,11 @@ fn deeply_nested_objects() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().response.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_response(expected, actual, &PactSpecification::V1).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_response(expected, actual, pact, &PactSpecification::V1).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -520,8 +568,8 @@ fn deeply_nested_objects() {
     }
 }
 
-#[test]
-fn objects_in_array_no_matches() {
+#[tokio::test]
+async fn objects_in_array_no_matches() {
     println!("FILE: tests/spec_testcases/v1/response/body/objects in array no matches.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -556,7 +604,11 @@ fn objects_in_array_no_matches() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().response.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_response(expected, actual, &PactSpecification::V1).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_response(expected, actual, pact, &PactSpecification::V1).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -565,8 +617,8 @@ fn objects_in_array_no_matches() {
     }
 }
 
-#[test]
-fn not_null_found_in_array_when_null_expected() {
+#[tokio::test]
+async fn not_null_found_in_array_when_null_expected() {
     println!("FILE: tests/spec_testcases/v1/response/body/not null found in array when null expected.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -601,7 +653,11 @@ fn not_null_found_in_array_when_null_expected() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().response.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_response(expected, actual, &PactSpecification::V1).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_response(expected, actual, pact, &PactSpecification::V1).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -610,8 +666,8 @@ fn not_null_found_in_array_when_null_expected() {
     }
 }
 
-#[test]
-fn different_value_found_at_index() {
+#[tokio::test]
+async fn different_value_found_at_index() {
     println!("FILE: tests/spec_testcases/v1/response/body/different value found at index.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -646,7 +702,11 @@ fn different_value_found_at_index() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().response.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_response(expected, actual, &PactSpecification::V1).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_response(expected, actual, pact, &PactSpecification::V1).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -655,8 +715,8 @@ fn different_value_found_at_index() {
     }
 }
 
-#[test]
-fn number_found_at_key_when_string_expected() {
+#[tokio::test]
+async fn number_found_at_key_when_string_expected() {
     println!("FILE: tests/spec_testcases/v1/response/body/number found at key when string expected.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -691,7 +751,11 @@ fn number_found_at_key_when_string_expected() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().response.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_response(expected, actual, &PactSpecification::V1).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_response(expected, actual, pact, &PactSpecification::V1).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -700,8 +764,8 @@ fn number_found_at_key_when_string_expected() {
     }
 }
 
-#[test]
-fn objects_in_array_second_matches() {
+#[tokio::test]
+async fn objects_in_array_second_matches() {
     println!("FILE: tests/spec_testcases/v1/response/body/objects in array second matches.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -735,7 +799,11 @@ fn objects_in_array_second_matches() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().response.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_response(expected, actual, &PactSpecification::V1).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_response(expected, actual, pact, &PactSpecification::V1).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -744,8 +812,8 @@ fn objects_in_array_second_matches() {
     }
 }
 
-#[test]
-fn missing_index() {
+#[tokio::test]
+async fn missing_index() {
     println!("FILE: tests/spec_testcases/v1/response/body/missing index.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -780,7 +848,11 @@ fn missing_index() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().response.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_response(expected, actual, &PactSpecification::V1).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_response(expected, actual, pact, &PactSpecification::V1).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -789,8 +861,8 @@ fn missing_index() {
     }
 }
 
-#[test]
-fn keys_out_of_order_match() {
+#[tokio::test]
+async fn keys_out_of_order_match() {
     println!("FILE: tests/spec_testcases/v1/response/body/keys out of order match.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -823,7 +895,11 @@ fn keys_out_of_order_match() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().response.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_response(expected, actual, &PactSpecification::V1).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_response(expected, actual, pact, &PactSpecification::V1).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -832,8 +908,8 @@ fn keys_out_of_order_match() {
     }
 }
 
-#[test]
-fn null_found_in_array_when_not_null_expected() {
+#[tokio::test]
+async fn null_found_in_array_when_not_null_expected() {
     println!("FILE: tests/spec_testcases/v1/response/body/null found in array when not null expected.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -868,7 +944,11 @@ fn null_found_in_array_when_not_null_expected() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().response.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_response(expected, actual, &PactSpecification::V1).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_response(expected, actual, pact, &PactSpecification::V1).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -877,8 +957,8 @@ fn null_found_in_array_when_not_null_expected() {
     }
 }
 
-#[test]
-fn unexpected_index_with_null_value() {
+#[tokio::test]
+async fn unexpected_index_with_null_value() {
     println!("FILE: tests/spec_testcases/v1/response/body/unexpected index with null value.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -913,7 +993,11 @@ fn unexpected_index_with_null_value() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().response.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_response(expected, actual, &PactSpecification::V1).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_response(expected, actual, pact, &PactSpecification::V1).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -922,8 +1006,8 @@ fn unexpected_index_with_null_value() {
     }
 }
 
-#[test]
-fn unexpected_key_with_not_null_value() {
+#[tokio::test]
+async fn unexpected_key_with_not_null_value() {
     println!("FILE: tests/spec_testcases/v1/response/body/unexpected key with not null value.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -959,7 +1043,11 @@ fn unexpected_key_with_not_null_value() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().response.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_response(expected, actual, &PactSpecification::V1).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_response(expected, actual, pact, &PactSpecification::V1).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -968,8 +1056,8 @@ fn unexpected_key_with_not_null_value() {
     }
 }
 
-#[test]
-fn string_found_at_key_when_number_expected() {
+#[tokio::test]
+async fn string_found_at_key_when_number_expected() {
     println!("FILE: tests/spec_testcases/v1/response/body/string found at key when number expected.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -1004,7 +1092,11 @@ fn string_found_at_key_when_number_expected() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().response.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_response(expected, actual, &PactSpecification::V1).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_response(expected, actual, pact, &PactSpecification::V1).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -1013,8 +1105,8 @@ fn string_found_at_key_when_number_expected() {
     }
 }
 
-#[test]
-fn missing_key() {
+#[tokio::test]
+async fn missing_key() {
     println!("FILE: tests/spec_testcases/v1/response/body/missing key.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -1050,7 +1142,11 @@ fn missing_key() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().response.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_response(expected, actual, &PactSpecification::V1).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_response(expected, actual, pact, &PactSpecification::V1).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -1059,8 +1155,8 @@ fn missing_key() {
     }
 }
 
-#[test]
-fn matches() {
+#[tokio::test]
+async fn matches() {
     println!("FILE: tests/spec_testcases/v1/response/body/matches.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -1099,7 +1195,11 @@ fn matches() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().response.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_response(expected, actual, &PactSpecification::V1).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_response(expected, actual, pact, &PactSpecification::V1).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -1108,8 +1208,8 @@ fn matches() {
     }
 }
 
-#[test]
-fn null_found_at_key_where_not_null_expected() {
+#[tokio::test]
+async fn null_found_at_key_where_not_null_expected() {
     println!("FILE: tests/spec_testcases/v1/response/body/null found at key where not null expected.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -1144,7 +1244,11 @@ fn null_found_at_key_where_not_null_expected() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().response.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_response(expected, actual, &PactSpecification::V1).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_response(expected, actual, pact, &PactSpecification::V1).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -1153,8 +1257,8 @@ fn null_found_at_key_where_not_null_expected() {
     }
 }
 
-#[test]
-fn plain_text_that_does_not_match() {
+#[tokio::test]
+async fn plain_text_that_does_not_match() {
     println!("FILE: tests/spec_testcases/v1/response/body/plain text that does not match.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -1181,7 +1285,11 @@ fn plain_text_that_does_not_match() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().response.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_response(expected, actual, &PactSpecification::V1).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_response(expected, actual, pact, &PactSpecification::V1).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
