@@ -7,12 +7,16 @@ use serde_json;
 #[allow(unused_imports)]
 use expectest::prelude::*;
 #[allow(unused_imports)]
+use pact_plugin_driver::catalogue_manager::register_core_entries;
+#[allow(unused_imports)]
 use pact_models::interaction::{Interaction, message_interaction_from_json};
 #[allow(unused_imports)]
 use pact_matching::match_interaction;
+#[allow(unused_imports)]
+use pact_models::prelude::{MessagePact, Pact};
 
-#[test]
-fn unexpected_index_with_not_null_value() {
+#[tokio::test]
+async fn unexpected_index_with_not_null_value() {
     println!("FILE: tests/spec_testcases/v3/message/body/unexpected index with not null value.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -55,7 +59,11 @@ fn unexpected_index_with_not_null_value() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V3).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V3).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -64,8 +72,8 @@ fn unexpected_index_with_not_null_value() {
     }
 }
 
-#[test]
-fn unexpected_key_with_null_value() {
+#[tokio::test]
+async fn unexpected_key_with_null_value() {
     println!("FILE: tests/spec_testcases/v3/message/body/unexpected key with null value.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -109,7 +117,11 @@ fn unexpected_key_with_null_value() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V3).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V3).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -118,8 +130,8 @@ fn unexpected_key_with_null_value() {
     }
 }
 
-#[test]
-fn different_value_found_at_key() {
+#[tokio::test]
+async fn different_value_found_at_key() {
     println!("FILE: tests/spec_testcases/v3/message/body/different value found at key.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -162,7 +174,11 @@ fn different_value_found_at_key() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V3).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V3).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -171,8 +187,8 @@ fn different_value_found_at_key() {
     }
 }
 
-#[test]
-fn not_null_found_at_key_when_null_expected() {
+#[tokio::test]
+async fn not_null_found_at_key_when_null_expected() {
     println!("FILE: tests/spec_testcases/v3/message/body/not null found at key when null expected.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -215,7 +231,11 @@ fn not_null_found_at_key_when_null_expected() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V3).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V3).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -224,8 +244,8 @@ fn not_null_found_at_key_when_null_expected() {
     }
 }
 
-#[test]
-fn array_with_regular_expression_in_element() {
+#[tokio::test]
+async fn array_with_regular_expression_in_element() {
     println!("FILE: tests/spec_testcases/v3/message/body/array with regular expression in element.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -301,7 +321,11 @@ fn array_with_regular_expression_in_element() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V3).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V3).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -310,8 +334,8 @@ fn array_with_regular_expression_in_element() {
     }
 }
 
-#[test]
-fn number_found_in_array_when_string_expected() {
+#[tokio::test]
+async fn number_found_in_array_when_string_expected() {
     println!("FILE: tests/spec_testcases/v3/message/body/number found in array when string expected.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -354,7 +378,11 @@ fn number_found_in_array_when_string_expected() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V3).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V3).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -363,8 +391,8 @@ fn number_found_in_array_when_string_expected() {
     }
 }
 
-#[test]
-fn array_in_different_order() {
+#[tokio::test]
+async fn array_in_different_order() {
     println!("FILE: tests/spec_testcases/v3/message/body/array in different order.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -407,7 +435,11 @@ fn array_in_different_order() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V3).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V3).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -416,8 +448,8 @@ fn array_in_different_order() {
     }
 }
 
-#[test]
-fn matches_with_regex_with_bracket_notation() {
+#[tokio::test]
+async fn matches_with_regex_with_bracket_notation() {
     println!("FILE: tests/spec_testcases/v3/message/body/matches with regex with bracket notation.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -472,7 +504,11 @@ fn matches_with_regex_with_bracket_notation() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V3).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V3).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -481,8 +517,8 @@ fn matches_with_regex_with_bracket_notation() {
     }
 }
 
-#[test]
-fn array_with_regular_expression_that_does_not_match_in_element() {
+#[tokio::test]
+async fn array_with_regular_expression_that_does_not_match_in_element() {
     println!("FILE: tests/spec_testcases/v3/message/body/array with regular expression that does not match in element.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -558,7 +594,11 @@ fn array_with_regular_expression_that_does_not_match_in_element() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V3).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V3).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -567,8 +607,8 @@ fn array_with_regular_expression_that_does_not_match_in_element() {
     }
 }
 
-#[test]
-fn array_size_less_than_required() {
+#[tokio::test]
+async fn array_size_less_than_required() {
     println!("FILE: tests/spec_testcases/v3/message/body/array size less than required.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -623,7 +663,11 @@ fn array_size_less_than_required() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V3).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V3).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -632,8 +676,8 @@ fn array_size_less_than_required() {
     }
 }
 
-#[test]
-fn array_with_nested_array_that_does_not_match() {
+#[tokio::test]
+async fn array_with_nested_array_that_does_not_match() {
     println!("FILE: tests/spec_testcases/v3/message/body/array with nested array that does not match.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -719,7 +763,11 @@ fn array_with_nested_array_that_does_not_match() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V3).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V3).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -728,8 +776,8 @@ fn array_with_nested_array_that_does_not_match() {
     }
 }
 
-#[test]
-fn string_found_in_array_when_number_expected() {
+#[tokio::test]
+async fn string_found_in_array_when_number_expected() {
     println!("FILE: tests/spec_testcases/v3/message/body/string found in array when number expected.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -772,7 +820,11 @@ fn string_found_in_array_when_number_expected() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V3).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V3).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -781,8 +833,8 @@ fn string_found_in_array_when_number_expected() {
     }
 }
 
-#[test]
-fn no_body() {
+#[tokio::test]
+async fn no_body() {
     println!("FILE: tests/spec_testcases/v3/message/body/no body.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -820,7 +872,11 @@ fn no_body() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V3).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V3).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -829,8 +885,8 @@ fn no_body() {
     }
 }
 
-#[test]
-fn array_at_top_level() {
+#[tokio::test]
+async fn array_at_top_level() {
     println!("FILE: tests/spec_testcases/v3/message/body/array at top level.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -891,7 +947,11 @@ fn array_at_top_level() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V3).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V3).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -900,8 +960,8 @@ fn array_at_top_level() {
     }
 }
 
-#[test]
-fn matches_with_type() {
+#[tokio::test]
+async fn matches_with_type() {
     println!("FILE: tests/spec_testcases/v3/message/body/matches with type.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -966,7 +1026,11 @@ fn matches_with_type() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V3).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V3).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -975,8 +1039,8 @@ fn matches_with_type() {
     }
 }
 
-#[test]
-fn no_body_no_content_type() {
+#[tokio::test]
+async fn no_body_no_content_type() {
     println!("FILE: tests/spec_testcases/v3/message/body/no body no content type.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -1010,7 +1074,11 @@ fn no_body_no_content_type() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V3).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V3).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -1019,8 +1087,8 @@ fn no_body_no_content_type() {
     }
 }
 
-#[test]
-fn not_null_found_in_array_when_null_expected() {
+#[tokio::test]
+async fn not_null_found_in_array_when_null_expected() {
     println!("FILE: tests/spec_testcases/v3/message/body/not null found in array when null expected.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -1063,7 +1131,11 @@ fn not_null_found_in_array_when_null_expected() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V3).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V3).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -1072,8 +1144,8 @@ fn not_null_found_in_array_when_null_expected() {
     }
 }
 
-#[test]
-fn array_with_at_least_one_element_not_matching_example_type() {
+#[tokio::test]
+async fn array_with_at_least_one_element_not_matching_example_type() {
     println!("FILE: tests/spec_testcases/v3/message/body/array with at least one element not matching example type.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -1141,7 +1213,11 @@ fn array_with_at_least_one_element_not_matching_example_type() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V3).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V3).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -1150,8 +1226,8 @@ fn array_with_at_least_one_element_not_matching_example_type() {
     }
 }
 
-#[test]
-fn different_value_found_at_index() {
+#[tokio::test]
+async fn different_value_found_at_index() {
     println!("FILE: tests/spec_testcases/v3/message/body/different value found at index.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -1194,7 +1270,11 @@ fn different_value_found_at_index() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V3).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V3).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -1203,8 +1283,8 @@ fn different_value_found_at_index() {
     }
 }
 
-#[test]
-fn array_with_nested_array_that_matches() {
+#[tokio::test]
+async fn array_with_nested_array_that_matches() {
     println!("FILE: tests/spec_testcases/v3/message/body/array with nested array that matches.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -1300,7 +1380,11 @@ fn array_with_nested_array_that_matches() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V3).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V3).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -1309,8 +1393,8 @@ fn array_with_nested_array_that_matches() {
     }
 }
 
-#[test]
-fn matches_with_regex() {
+#[tokio::test]
+async fn matches_with_regex() {
     println!("FILE: tests/spec_testcases/v3/message/body/matches with regex.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -1385,7 +1469,11 @@ fn matches_with_regex() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V3).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V3).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -1394,8 +1482,8 @@ fn matches_with_regex() {
     }
 }
 
-#[test]
-fn number_found_at_key_when_string_expected() {
+#[tokio::test]
+async fn number_found_at_key_when_string_expected() {
     println!("FILE: tests/spec_testcases/v3/message/body/number found at key when string expected.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -1438,7 +1526,11 @@ fn number_found_at_key_when_string_expected() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V3).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V3).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -1447,8 +1539,8 @@ fn number_found_at_key_when_string_expected() {
     }
 }
 
-#[test]
-fn missing_index() {
+#[tokio::test]
+async fn missing_index() {
     println!("FILE: tests/spec_testcases/v3/message/body/missing index.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -1491,7 +1583,11 @@ fn missing_index() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V3).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V3).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -1500,8 +1596,8 @@ fn missing_index() {
     }
 }
 
-#[test]
-fn null_found_in_array_when_not_null_expected() {
+#[tokio::test]
+async fn null_found_in_array_when_not_null_expected() {
     println!("FILE: tests/spec_testcases/v3/message/body/null found in array when not null expected.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -1544,7 +1640,11 @@ fn null_found_in_array_when_not_null_expected() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V3).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V3).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -1553,8 +1653,8 @@ fn null_found_in_array_when_not_null_expected() {
     }
 }
 
-#[test]
-fn unexpected_index_with_null_value() {
+#[tokio::test]
+async fn unexpected_index_with_null_value() {
     println!("FILE: tests/spec_testcases/v3/message/body/unexpected index with null value.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -1597,7 +1697,11 @@ fn unexpected_index_with_null_value() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V3).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V3).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -1606,8 +1710,8 @@ fn unexpected_index_with_null_value() {
     }
 }
 
-#[test]
-fn unexpected_key_with_not_null_value() {
+#[tokio::test]
+async fn unexpected_key_with_not_null_value() {
     println!("FILE: tests/spec_testcases/v3/message/body/unexpected key with not null value.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -1651,7 +1755,11 @@ fn unexpected_key_with_not_null_value() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V3).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V3).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -1660,8 +1768,8 @@ fn unexpected_key_with_not_null_value() {
     }
 }
 
-#[test]
-fn string_found_at_key_when_number_expected() {
+#[tokio::test]
+async fn string_found_at_key_when_number_expected() {
     println!("FILE: tests/spec_testcases/v3/message/body/string found at key when number expected.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -1704,7 +1812,11 @@ fn string_found_at_key_when_number_expected() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V3).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V3).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -1713,8 +1825,8 @@ fn string_found_at_key_when_number_expected() {
     }
 }
 
-#[test]
-fn missing_key() {
+#[tokio::test]
+async fn missing_key() {
     println!("FILE: tests/spec_testcases/v3/message/body/missing key.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -1758,7 +1870,11 @@ fn missing_key() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V3).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V3).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -1767,8 +1883,8 @@ fn missing_key() {
     }
 }
 
-#[test]
-fn array_with_at_least_one_element_matching_by_example() {
+#[tokio::test]
+async fn array_with_at_least_one_element_matching_by_example() {
     println!("FILE: tests/spec_testcases/v3/message/body/array with at least one element matching by example.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -1836,7 +1952,11 @@ fn array_with_at_least_one_element_matching_by_example() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V3).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V3).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -1845,8 +1965,8 @@ fn array_with_at_least_one_element_matching_by_example() {
     }
 }
 
-#[test]
-fn matches() {
+#[tokio::test]
+async fn matches() {
     println!("FILE: tests/spec_testcases/v3/message/body/matches.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -1893,7 +2013,11 @@ fn matches() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V3).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V3).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -1902,8 +2026,8 @@ fn matches() {
     }
 }
 
-#[test]
-fn null_found_at_key_where_not_null_expected() {
+#[tokio::test]
+async fn null_found_at_key_where_not_null_expected() {
     println!("FILE: tests/spec_testcases/v3/message/body/null found at key where not null expected.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -1946,7 +2070,11 @@ fn null_found_at_key_where_not_null_expected() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V3).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V3).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
