@@ -7,12 +7,16 @@ use serde_json;
 #[allow(unused_imports)]
 use expectest::prelude::*;
 #[allow(unused_imports)]
+use pact_plugin_driver::catalogue_manager::register_core_entries;
+#[allow(unused_imports)]
 use pact_models::interaction::{Interaction, message_interaction_from_json};
 #[allow(unused_imports)]
 use pact_matching::match_interaction;
+#[allow(unused_imports)]
+use pact_models::prelude::{MessagePact, Pact};
 
-#[test]
-fn unexpected_index_with_not_null_value() {
+#[tokio::test]
+async fn unexpected_index_with_not_null_value() {
     println!("FILE: tests/spec_testcases/v4/message/body/unexpected index with not null value.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -64,7 +68,11 @@ fn unexpected_index_with_not_null_value() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V4).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V4).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -73,8 +81,8 @@ fn unexpected_index_with_not_null_value() {
     }
 }
 
-#[test]
-fn unexpected_key_with_null_value() {
+#[tokio::test]
+async fn unexpected_key_with_null_value() {
     println!("FILE: tests/spec_testcases/v4/message/body/unexpected key with null value.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -120,7 +128,11 @@ fn unexpected_key_with_null_value() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V4).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V4).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -129,8 +141,8 @@ fn unexpected_key_with_null_value() {
     }
 }
 
-#[test]
-fn different_value_found_at_key() {
+#[tokio::test]
+async fn different_value_found_at_key() {
     println!("FILE: tests/spec_testcases/v4/message/body/different value found at key.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -175,7 +187,11 @@ fn different_value_found_at_key() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V4).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V4).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -184,8 +200,8 @@ fn different_value_found_at_key() {
     }
 }
 
-#[test]
-fn not_null_found_at_key_when_null_expected() {
+#[tokio::test]
+async fn not_null_found_at_key_when_null_expected() {
     println!("FILE: tests/spec_testcases/v4/message/body/not null found at key when null expected.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -230,7 +246,11 @@ fn not_null_found_at_key_when_null_expected() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V4).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V4).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -239,8 +259,8 @@ fn not_null_found_at_key_when_null_expected() {
     }
 }
 
-#[test]
-fn array_with_regular_expression_in_element() {
+#[tokio::test]
+async fn array_with_regular_expression_in_element() {
     println!("FILE: tests/spec_testcases/v4/message/body/array with regular expression in element.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -319,7 +339,11 @@ fn array_with_regular_expression_in_element() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V4).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V4).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -328,8 +352,8 @@ fn array_with_regular_expression_in_element() {
     }
 }
 
-#[test]
-fn number_found_in_array_when_string_expected() {
+#[tokio::test]
+async fn number_found_in_array_when_string_expected() {
     println!("FILE: tests/spec_testcases/v4/message/body/number found in array when string expected.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -382,7 +406,11 @@ fn number_found_in_array_when_string_expected() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V4).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V4).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -391,8 +419,8 @@ fn number_found_in_array_when_string_expected() {
     }
 }
 
-#[test]
-fn array_in_different_order() {
+#[tokio::test]
+async fn array_in_different_order() {
     println!("FILE: tests/spec_testcases/v4/message/body/array in different order.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -443,7 +471,11 @@ fn array_in_different_order() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V4).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V4).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -452,8 +484,8 @@ fn array_in_different_order() {
     }
 }
 
-#[test]
-fn matches_with_regex_with_bracket_notation() {
+#[tokio::test]
+async fn matches_with_regex_with_bracket_notation() {
     println!("FILE: tests/spec_testcases/v4/message/body/matches with regex with bracket notation.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -510,7 +542,11 @@ fn matches_with_regex_with_bracket_notation() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V4).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V4).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -519,8 +555,8 @@ fn matches_with_regex_with_bracket_notation() {
     }
 }
 
-#[test]
-fn array_with_regular_expression_that_does_not_match_in_element() {
+#[tokio::test]
+async fn array_with_regular_expression_that_does_not_match_in_element() {
     println!("FILE: tests/spec_testcases/v4/message/body/array with regular expression that does not match in element.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -599,7 +635,11 @@ fn array_with_regular_expression_that_does_not_match_in_element() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V4).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V4).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -608,8 +648,8 @@ fn array_with_regular_expression_that_does_not_match_in_element() {
     }
 }
 
-#[test]
-fn array_size_less_than_required() {
+#[tokio::test]
+async fn array_size_less_than_required() {
     println!("FILE: tests/spec_testcases/v4/message/body/array size less than required.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -666,7 +706,11 @@ fn array_size_less_than_required() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V4).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V4).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -675,8 +719,8 @@ fn array_size_less_than_required() {
     }
 }
 
-#[test]
-fn array_with_nested_array_that_does_not_match() {
+#[tokio::test]
+async fn array_with_nested_array_that_does_not_match() {
     println!("FILE: tests/spec_testcases/v4/message/body/array with nested array that does not match.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -768,7 +812,11 @@ fn array_with_nested_array_that_does_not_match() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V4).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V4).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -777,8 +825,8 @@ fn array_with_nested_array_that_does_not_match() {
     }
 }
 
-#[test]
-fn string_found_in_array_when_number_expected() {
+#[tokio::test]
+async fn string_found_in_array_when_number_expected() {
     println!("FILE: tests/spec_testcases/v4/message/body/string found in array when number expected.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -831,7 +879,11 @@ fn string_found_in_array_when_number_expected() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V4).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V4).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -840,8 +892,8 @@ fn string_found_in_array_when_number_expected() {
     }
 }
 
-#[test]
-fn no_body() {
+#[tokio::test]
+async fn no_body() {
     println!("FILE: tests/spec_testcases/v4/message/body/no body.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -877,7 +929,11 @@ fn no_body() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V4).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V4).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -886,8 +942,8 @@ fn no_body() {
     }
 }
 
-#[test]
-fn array_at_top_level() {
+#[tokio::test]
+async fn array_at_top_level() {
     println!("FILE: tests/spec_testcases/v4/message/body/array at top level.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -950,7 +1006,11 @@ fn array_at_top_level() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V4).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V4).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -959,8 +1019,8 @@ fn array_at_top_level() {
     }
 }
 
-#[test]
-fn matches_with_type() {
+#[tokio::test]
+async fn matches_with_type() {
     println!("FILE: tests/spec_testcases/v4/message/body/matches with type.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -1033,7 +1093,11 @@ fn matches_with_type() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V4).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V4).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -1042,8 +1106,8 @@ fn matches_with_type() {
     }
 }
 
-#[test]
-fn no_body_no_content_type() {
+#[tokio::test]
+async fn no_body_no_content_type() {
     println!("FILE: tests/spec_testcases/v4/message/body/no body no content type.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -1078,7 +1142,11 @@ fn no_body_no_content_type() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V4).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V4).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -1087,8 +1155,8 @@ fn no_body_no_content_type() {
     }
 }
 
-#[test]
-fn not_null_found_in_array_when_null_expected() {
+#[tokio::test]
+async fn not_null_found_in_array_when_null_expected() {
     println!("FILE: tests/spec_testcases/v4/message/body/not null found in array when null expected.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -1141,7 +1209,11 @@ fn not_null_found_in_array_when_null_expected() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V4).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V4).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -1150,8 +1222,8 @@ fn not_null_found_in_array_when_null_expected() {
     }
 }
 
-#[test]
-fn array_with_at_least_one_element_not_matching_example_type() {
+#[tokio::test]
+async fn array_with_at_least_one_element_not_matching_example_type() {
     println!("FILE: tests/spec_testcases/v4/message/body/array with at least one element not matching example type.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -1222,7 +1294,11 @@ fn array_with_at_least_one_element_not_matching_example_type() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V4).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V4).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -1231,8 +1307,8 @@ fn array_with_at_least_one_element_not_matching_example_type() {
     }
 }
 
-#[test]
-fn different_value_found_at_index() {
+#[tokio::test]
+async fn different_value_found_at_index() {
     println!("FILE: tests/spec_testcases/v4/message/body/different value found at index.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -1283,7 +1359,11 @@ fn different_value_found_at_index() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V4).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V4).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -1292,8 +1372,8 @@ fn different_value_found_at_index() {
     }
 }
 
-#[test]
-fn array_with_nested_array_that_matches() {
+#[tokio::test]
+async fn array_with_nested_array_that_matches() {
     println!("FILE: tests/spec_testcases/v4/message/body/array with nested array that matches.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -1400,7 +1480,11 @@ fn array_with_nested_array_that_matches() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V4).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V4).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -1409,8 +1493,8 @@ fn array_with_nested_array_that_matches() {
     }
 }
 
-#[test]
-fn matches_with_regex() {
+#[tokio::test]
+async fn matches_with_regex() {
     println!("FILE: tests/spec_testcases/v4/message/body/matches with regex.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -1493,7 +1577,11 @@ fn matches_with_regex() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V4).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V4).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -1502,8 +1590,8 @@ fn matches_with_regex() {
     }
 }
 
-#[test]
-fn number_found_at_key_when_string_expected() {
+#[tokio::test]
+async fn number_found_at_key_when_string_expected() {
     println!("FILE: tests/spec_testcases/v4/message/body/number found at key when string expected.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -1548,7 +1636,11 @@ fn number_found_at_key_when_string_expected() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V4).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V4).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -1557,8 +1649,8 @@ fn number_found_at_key_when_string_expected() {
     }
 }
 
-#[test]
-fn missing_index() {
+#[tokio::test]
+async fn missing_index() {
     println!("FILE: tests/spec_testcases/v4/message/body/missing index.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -1608,7 +1700,11 @@ fn missing_index() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V4).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V4).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -1617,8 +1713,8 @@ fn missing_index() {
     }
 }
 
-#[test]
-fn null_found_in_array_when_not_null_expected() {
+#[tokio::test]
+async fn null_found_in_array_when_not_null_expected() {
     println!("FILE: tests/spec_testcases/v4/message/body/null found in array when not null expected.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -1671,7 +1767,11 @@ fn null_found_in_array_when_not_null_expected() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V4).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V4).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -1680,8 +1780,8 @@ fn null_found_in_array_when_not_null_expected() {
     }
 }
 
-#[test]
-fn unexpected_index_with_null_value() {
+#[tokio::test]
+async fn unexpected_index_with_null_value() {
     println!("FILE: tests/spec_testcases/v4/message/body/unexpected index with null value.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -1733,7 +1833,11 @@ fn unexpected_index_with_null_value() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V4).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V4).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -1742,8 +1846,8 @@ fn unexpected_index_with_null_value() {
     }
 }
 
-#[test]
-fn unexpected_key_with_not_null_value() {
+#[tokio::test]
+async fn unexpected_key_with_not_null_value() {
     println!("FILE: tests/spec_testcases/v4/message/body/unexpected key with not null value.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -1789,7 +1893,11 @@ fn unexpected_key_with_not_null_value() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V4).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V4).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -1798,8 +1906,8 @@ fn unexpected_key_with_not_null_value() {
     }
 }
 
-#[test]
-fn string_found_at_key_when_number_expected() {
+#[tokio::test]
+async fn string_found_at_key_when_number_expected() {
     println!("FILE: tests/spec_testcases/v4/message/body/string found at key when number expected.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -1844,7 +1952,11 @@ fn string_found_at_key_when_number_expected() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V4).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V4).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -1853,8 +1965,8 @@ fn string_found_at_key_when_number_expected() {
     }
 }
 
-#[test]
-fn missing_key() {
+#[tokio::test]
+async fn missing_key() {
     println!("FILE: tests/spec_testcases/v4/message/body/missing key.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -1900,7 +2012,11 @@ fn missing_key() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V4).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V4).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -1909,8 +2025,8 @@ fn missing_key() {
     }
 }
 
-#[test]
-fn array_with_at_least_one_element_matching_by_example() {
+#[tokio::test]
+async fn array_with_at_least_one_element_matching_by_example() {
     println!("FILE: tests/spec_testcases/v4/message/body/array with at least one element matching by example.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -1981,7 +2097,11 @@ fn array_with_at_least_one_element_matching_by_example() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V4).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V4).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -1990,8 +2110,8 @@ fn array_with_at_least_one_element_matching_by_example() {
     }
 }
 
-#[test]
-fn matches() {
+#[tokio::test]
+async fn matches() {
     println!("FILE: tests/spec_testcases/v4/message/body/matches.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -2046,7 +2166,11 @@ fn matches() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V4).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V4).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -2055,8 +2179,8 @@ fn matches() {
     }
 }
 
-#[test]
-fn null_found_at_key_where_not_null_expected() {
+#[tokio::test]
+async fn null_found_at_key_where_not_null_expected() {
     println!("FILE: tests/spec_testcases/v4/message/body/null found at key where not null expected.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -2101,7 +2225,11 @@ fn null_found_at_key_where_not_null_expected() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_message().unwrap().contents.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction(expected, actual, &PactSpecification::V4).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = MessagePact { messages: vec![ expected.as_message().unwrap_or_default() ], .. MessagePact::default() }.boxed();
+    let result = match_interaction(expected, actual, pact, &PactSpecification::V4).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
