@@ -7,12 +7,16 @@ use serde_json;
 #[allow(unused_imports)]
 use expectest::prelude::*;
 #[allow(unused_imports)]
+use pact_plugin_driver::catalogue_manager::register_core_entries;
+#[allow(unused_imports)]
 use pact_models::interaction::{Interaction, http_interaction_from_json};
 #[allow(unused_imports)]
 use pact_matching::{match_interaction_request, match_interaction_response};
+#[allow(unused_imports)]
+use pact_models::prelude::{Pact, RequestResponsePact};
 
-#[test]
-fn order_of_comma_separated_header_values_different() {
+#[tokio::test]
+async fn order_of_comma_separated_header_values_different() {
     println!("FILE: tests/spec_testcases/v4/response/headers/order of comma separated header values different.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -41,7 +45,11 @@ fn order_of_comma_separated_header_values_different() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().response.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_response(expected, actual, &PactSpecification::V4).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_response(expected, actual, pact, &PactSpecification::V4).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -50,8 +58,8 @@ fn order_of_comma_separated_header_values_different() {
     }
 }
 
-#[test]
-fn matches_content_type_with_charset_with_different_case() {
+#[tokio::test]
+async fn matches_content_type_with_charset_with_different_case() {
     println!("FILE: tests/spec_testcases/v4/response/headers/matches content type with charset with different case.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -82,7 +90,11 @@ fn matches_content_type_with_charset_with_different_case() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().response.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_response(expected, actual, &PactSpecification::V4).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_response(expected, actual, pact, &PactSpecification::V4).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -91,8 +103,8 @@ fn matches_content_type_with_charset_with_different_case() {
     }
 }
 
-#[test]
-fn whitespace_after_comma_different() {
+#[tokio::test]
+async fn whitespace_after_comma_different() {
     println!("FILE: tests/spec_testcases/v4/response/headers/whitespace after comma different.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -121,7 +133,11 @@ fn whitespace_after_comma_different() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().response.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_response(expected, actual, &PactSpecification::V4).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_response(expected, actual, pact, &PactSpecification::V4).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -130,8 +146,8 @@ fn whitespace_after_comma_different() {
     }
 }
 
-#[test]
-fn header_value_is_different_case() {
+#[tokio::test]
+async fn header_value_is_different_case() {
     println!("FILE: tests/spec_testcases/v4/response/headers/header value is different case.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -160,7 +176,11 @@ fn header_value_is_different_case() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().response.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_response(expected, actual, &PactSpecification::V4).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_response(expected, actual, pact, &PactSpecification::V4).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -169,8 +189,8 @@ fn header_value_is_different_case() {
     }
 }
 
-#[test]
-fn matches_content_type_with_parameters_in_different_order() {
+#[tokio::test]
+async fn matches_content_type_with_parameters_in_different_order() {
     println!("FILE: tests/spec_testcases/v4/response/headers/matches content type with parameters in different order.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -199,7 +219,11 @@ fn matches_content_type_with_parameters_in_different_order() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().response.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_response(expected, actual, &PactSpecification::V4).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_response(expected, actual, pact, &PactSpecification::V4).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -208,8 +232,8 @@ fn matches_content_type_with_parameters_in_different_order() {
     }
 }
 
-#[test]
-fn header_name_is_different_case() {
+#[tokio::test]
+async fn header_name_is_different_case() {
     println!("FILE: tests/spec_testcases/v4/response/headers/header name is different case.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -238,7 +262,11 @@ fn header_name_is_different_case() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().response.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_response(expected, actual, &PactSpecification::V4).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_response(expected, actual, pact, &PactSpecification::V4).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -247,8 +275,8 @@ fn header_name_is_different_case() {
     }
 }
 
-#[test]
-fn matches_with_regex() {
+#[tokio::test]
+async fn matches_with_regex() {
     println!("FILE: tests/spec_testcases/v4/response/headers/matches with regex.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -291,7 +319,11 @@ fn matches_with_regex() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().response.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_response(expected, actual, &PactSpecification::V4).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_response(expected, actual, pact, &PactSpecification::V4).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -300,8 +332,8 @@ fn matches_with_regex() {
     }
 }
 
-#[test]
-fn unexpected_header_found() {
+#[tokio::test]
+async fn unexpected_header_found() {
     println!("FILE: tests/spec_testcases/v4/response/headers/unexpected header found.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -328,7 +360,11 @@ fn unexpected_header_found() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().response.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_response(expected, actual, &PactSpecification::V4).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_response(expected, actual, pact, &PactSpecification::V4).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -337,8 +373,8 @@ fn unexpected_header_found() {
     }
 }
 
-#[test]
-fn content_type_parameters_do_not_match() {
+#[tokio::test]
+async fn content_type_parameters_do_not_match() {
     println!("FILE: tests/spec_testcases/v4/response/headers/content type parameters do not match.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -367,7 +403,11 @@ fn content_type_parameters_do_not_match() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().response.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_response(expected, actual, &PactSpecification::V4).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_response(expected, actual, pact, &PactSpecification::V4).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -376,8 +416,8 @@ fn content_type_parameters_do_not_match() {
     }
 }
 
-#[test]
-fn matches() {
+#[tokio::test]
+async fn matches() {
     println!("FILE: tests/spec_testcases/v4/response/headers/matches.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -408,7 +448,11 @@ fn matches() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().response.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_response(expected, actual, &PactSpecification::V4).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_response(expected, actual, pact, &PactSpecification::V4).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -417,8 +461,8 @@ fn matches() {
     }
 }
 
-#[test]
-fn matches_content_type_with_charset() {
+#[tokio::test]
+async fn matches_content_type_with_charset() {
     println!("FILE: tests/spec_testcases/v4/response/headers/matches content type with charset.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -447,7 +491,11 @@ fn matches_content_type_with_charset() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().response.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_response(expected, actual, &PactSpecification::V4).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_response(expected, actual, pact, &PactSpecification::V4).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
@@ -456,8 +504,8 @@ fn matches_content_type_with_charset() {
     }
 }
 
-#[test]
-fn empty_headers() {
+#[tokio::test]
+async fn empty_headers() {
     println!("FILE: tests/spec_testcases/v4/response/headers/empty headers.json");
     #[allow(unused_mut)]
     let mut pact: serde_json::Value = serde_json::from_str(r#"
@@ -482,7 +530,11 @@ fn empty_headers() {
     println!("ACTUAL: {:?}", actual);
     println!("BODY: {}", actual.as_request_response().unwrap().response.body.str_value());
     let pact_match = pact.get("match").unwrap();
-    let result = match_interaction_response(expected, actual, &PactSpecification::V4).unwrap();
+
+    pact_matching::matchers::configure_core_catalogue();
+    let pact = RequestResponsePact { interactions: vec![ expected.as_request_response().unwrap_or_default() ], .. RequestResponsePact::default() }.boxed();
+    let result = match_interaction_response(expected, actual, pact, &PactSpecification::V4).await.unwrap();
+
     println!("RESULT: {:?}", result);
     if pact_match.as_bool().unwrap() {
        expect!(result.iter()).to(be_empty());
